/*******************************************************************************
* File Name: Comp_vref_PM.c  
* Version 1.60
*
*  Description:
*     This file provides the power management source code to API for the
*     Comparator.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include "Comp_vref.h"

static Comp_vref_backupStruct Comp_vref_backup;


/*******************************************************************************
* Function Name: Comp_vref_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void Comp_vref_SaveConfig(void)
{
    /* Empty since all are system reset for retention flops */
}


/*******************************************************************************
* Function Name: Comp_vref_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void Comp_vref_RestoreConfig(void)
{
    /* Empty since all are system reset for retention flops */    
}


/*******************************************************************************
* Function Name: Comp_vref_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  Comp_vref_backup.enableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Comp_vref_Sleep(void)
{
    /* Save Comp's enable state */    
    if(Comp_vref_ACT_PWR_EN == (Comp_vref_PWRMGR & Comp_vref_ACT_PWR_EN))
    {
        /* Comp is enabled */
        Comp_vref_backup.enableState = 1u;
    }
    else
    {
        /* Comp is disabled */
        Comp_vref_backup.enableState = 0u;
    }    
    
    Comp_vref_Stop();
    Comp_vref_SaveConfig();
}


/*******************************************************************************
* Function Name: Comp_vref_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Comp_vref_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Comp_vref_Wakeup(void) 
{
    Comp_vref_RestoreConfig();
    
    if(Comp_vref_backup.enableState == 1u)
    {
        /* Enable Comp's operation */
        Comp_vref_Enable();

    } /* Do nothing if Comp was disabled before */    
    
}


/* [] END OF FILE */
