/*******************************************************************************
* File Name: Contrast.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Contrast.h"


/*******************************************************************************
* Function Name: Contrast_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void Contrast_Write(uint8 value)
{
    uint8 staticBits = Contrast_DR & ~Contrast_MASK;
    Contrast_DR = staticBits | ((value << Contrast_SHIFT) & Contrast_MASK);
}


/*******************************************************************************
* Function Name: Contrast_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void Contrast_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(Contrast_0, mode);
}


/*******************************************************************************
* Function Name: Contrast_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Contrast_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Contrast_Read(void)
{
    return (Contrast_PS & Contrast_MASK) >> Contrast_SHIFT;
}


/*******************************************************************************
* Function Name: Contrast_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Contrast_ReadDataReg(void)
{
    return (Contrast_DR & Contrast_MASK) >> Contrast_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Contrast_INTSTAT) 

    /*******************************************************************************
    * Function Name: Contrast_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Contrast_ClearInterrupt(void)
    {
        return (Contrast_INTSTAT & Contrast_MASK) >> Contrast_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
