/*******************************************************************************
* File Name: DAC_Buffer.c
* Version 1.10
*
* Description:
*   This file provides the source code to the API for the OpAmp (Analog Buffer) 
*   User Module.
*
* NOTE:
* 
*
*******************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "DAC_Buffer.h"

uint8  DAC_Buffer_initVar = 0;

/*******************************************************************************
* Funciton Name:   DAC_Buffer_Start
********************************************************************************
*
* Summary:
*  The start function initializes the Analog Buffer with the default values, and 
*  sets the power to the given level.  A power level of 0, is the same as 
*  executing the stop function.
*
* Parameters: 
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void DAC_Buffer_Start(void) 
{
   if(DAC_Buffer_initVar == 0)
   {
      DAC_Buffer_initVar = 1;
      DAC_Buffer_SetPower(DAC_Buffer_DEFAULT_POWER);

      /* Set follower mode if selected */
      DAC_Buffer_SW |= DAC_Buffer_DEFAULT_MODE;
   }

   /* Enable power to buffer */
   DAC_Buffer_PWRMGR |= DAC_Buffer_ACT_PWR_EN;

}

/*******************************************************************************
* Function Name: DAC_Buffer_Stop
********************************************************************************
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:  
*   (void)
*
* Return:  
*   (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void DAC_Buffer_Stop(void)
{
   /* Disable power to buffer */
   DAC_Buffer_PWRMGR &= ~DAC_Buffer_ACT_PWR_EN;
}

/*******************************************************************************
* Funciton Name:   DAC_Buffer_SetPower
********************************************************************************
*
* Summary:
*  Sets power level of Analog buffer.
*
* Parameters: 
*    power:   Sets power level between low (1) and high power (3).
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void DAC_Buffer_SetPower(uint8 power) 
{
      DAC_Buffer_CR &= ~DAC_Buffer_PWR_MASK;             /* Clear power setting  */
      DAC_Buffer_CR |= ( power & DAC_Buffer_PWR_MASK);   /* Set device power     */
}
/* [] END OF FILE */


