/*******************************************************************************
* File Name: DMA_Trigger.c  
* Version 1.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "DMA_Trigger.h"


/*******************************************************************************
* Function Name: DMA_Trigger_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void DMA_Trigger_Write(uint8 value)
{
    uint8 staticBits = DMA_Trigger_DR & ~DMA_Trigger_MASK;
    DMA_Trigger_DR = staticBits | ((value << DMA_Trigger_SHIFT) & DMA_Trigger_MASK);
}


/*******************************************************************************
* Function Name: DMA_Trigger_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void DMA_Trigger_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(DMA_Trigger_0, mode);
}


/*******************************************************************************
* Function Name: DMA_Trigger_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DMA_Trigger_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DMA_Trigger_Read(void)
{
    return (DMA_Trigger_PS & DMA_Trigger_MASK) >> DMA_Trigger_SHIFT;
}


/*******************************************************************************
* Function Name: DMA_Trigger_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DMA_Trigger_ReadDataReg(void)
{
    return (DMA_Trigger_DR & DMA_Trigger_MASK) >> DMA_Trigger_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DMA_Trigger_INTSTAT) 

    /*******************************************************************************
    * Function Name: DMA_Trigger_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DMA_Trigger_ClearInterrupt(void)
    {
        return (DMA_Trigger_INTSTAT & DMA_Trigger_MASK) >> DMA_Trigger_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
