/*******************************************************************************
* File Name: Excitation_Drive.h  
* Version 1.10
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the OpAmp (Analog Buffer) User Module.
*
*   Note:
*     
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_OPAMP_Excitation_Drive_H) 
#define CY_OPAMP_Excitation_Drive_H 

/**************************************
*        Function Prototypes 
**************************************/

void    Excitation_Drive_Start(void);
void    Excitation_Drive_Stop(void);
void    Excitation_Drive_SetPower(uint8 power);


/**************************************
*           API Constants        
**************************************/

/* Power constants for SetPower() function */
#define Excitation_Drive_LOWPOWER    0x01u
#define Excitation_Drive_MEDPOWER    0x02u
#define Excitation_Drive_HIGHPOWER   0x03u


/**************************************
*           Parameter Defaults        
**************************************/

#define Excitation_Drive_DEFAULT_POWER    3 
#define Excitation_Drive_DEFAULT_MODE     1 

/**************************************
*       Register Constants        
**************************************/

/* CX Analog Buffer Input Selection Register */

/* Power mode defines.                  */
#define Excitation_Drive_PWR_MASK    0x03u 
#define Excitation_Drive_PWR_SLOW    0x01u
#define Excitation_Drive_PWR_MEDIUM  0x02u
#define Excitation_Drive_PWR_FAST    0x03u

/* MX Analog Buffer Input Selection Register */

/* Bit Field  MX_VN                     */
#define Excitation_Drive_MX_VN_MASK  0x30u 
#define Excitation_Drive_MX_VN_NC    0x00u 
#define Excitation_Drive_MX_VN_AG4   0x20u 
#define Excitation_Drive_MX_VN_AG6   0x30u 

/* Bit Field  MX_VP                     */
#define Excitation_Drive_MX_VP_MASK  0x0Fu 
#define Excitation_Drive_MX_VP_NC    0x00u 
#define Excitation_Drive_MX_VP_VREF  0x07u 
#define Excitation_Drive_MX_VP_AG4   0x08u 
#define Excitation_Drive_MX_VP_AG5   0x09u 
#define Excitation_Drive_MX_VP_AG6   0x0Au 
#define Excitation_Drive_MX_VP_AG7   0x08u 
#define Excitation_Drive_MX_VP_ABUS0 0x0Cu 
#define Excitation_Drive_MX_VP_ABUS1 0x0Du 
#define Excitation_Drive_MX_VP_ABUS2 0x0Eu 
#define Excitation_Drive_MX_VP_ABUS3 0x0Fu 

/* SW Analog Buffer Routing Switch Reg  */

/* Bit Field  SW                        */
#define Excitation_Drive_SW_MASK     0x07u 
#define Excitation_Drive_SW_SWINP    0x04u  /* Enable positive input */
#define Excitation_Drive_SW_SWINN    0x02u  /* Enable negative input */
#define Excitation_Drive_SW_SWFOL    0x01u  /* Enable follower mode  */

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define Excitation_Drive_ACT_PWR_EN   Excitation_Drive_ABuf__PM_ACT_MSK /* Power enable mask */

/***********************************************/
/* ANIF.PUMP.CR1 Pump Configuration Register 1 */
/***********************************************/
#define Excitation_Drive_PUMP_CR1  (* (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)

#define Excitation_Drive_PUMP_CR1_CLKSEL  0x40
#define Excitation_Drive_PUMP_CR1_FORCE   0x20
#define Excitation_Drive_PUMP_CR1_AUTO    0x10

/**************************************
*             Registers        
**************************************/

#define Excitation_Drive_CR    	(* (reg8 *) Excitation_Drive_ABuf__CR )
#define Excitation_Drive_MX    	(* (reg8 *) Excitation_Drive_ABuf__MX )
#define Excitation_Drive_SW    	(* (reg8 *) Excitation_Drive_ABuf__SW )
#define Excitation_Drive_PWRMGR  (* (reg8 *) Excitation_Drive_ABuf__PM_ACT_CFG )  /* Power manager */

#endif /* CY_OPAMP_Excitation_Drive_H */

/* [] END OF FILE */
