/*******************************************************************************
* File Name: Excite_Drive.h  
* Version 1.10
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the TIA User Module.
*
*   Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_TIA_Excite_Drive_H) 
#define CY_TIA_Excite_Drive_H 

/***************************************
*        Function Prototypes 
***************************************/

void    Excite_Drive_Start(void);
void    Excite_Drive_Stop(void);
void    Excite_Drive_SetPower(uint8 power);
void    Excite_Drive_SetResFB(uint8 res_feedback);
void    Excite_Drive_SetCapFB(uint8 cap_feedback);


/***************************************
*       Initial Paramater Values
***************************************/

#define Excite_Drive_INIT_POWER 		3
#define Excite_Drive_INIT_RES_FEEDBACK	2
#define Excite_Drive_INIT_CAP_FEEDBACK	0
#define Excite_Drive_MIN_VDDA           0

/***************************************
*              Constants        
***************************************/
/* Constants for Minimum Vdda paramater */
#define  Excite_Drive_MIN_VDDA_GTE_2_7V     0x00u
#define  Excite_Drive_MIN_VDDA_LT_2_7V		0x01u

/* Power constants for SetPower function */
#define Excite_Drive_MINPOWER               0x00u
#define Excite_Drive_LOWPOWER               0x01u
#define Excite_Drive_MEDPOWER               0x02u
#define Excite_Drive_HIGHPOWER              0x03u

/* Constants for SetResFB function */
#define Excite_Drive_RES_FEEDBACK_20K       0x00u
#define Excite_Drive_RES_FEEDBACK_30K       0x01u
#define Excite_Drive_RES_FEEDBACK_40K       0x02u
#define Excite_Drive_RES_FEEDBACK_80K       0x03u
#define Excite_Drive_RES_FEEDBACK_120K      0x04u
#define Excite_Drive_RES_FEEDBACK_250K      0x05u
#define Excite_Drive_RES_FEEDBACK_500K      0x06u
#define Excite_Drive_RES_FEEDBACK_1000K     0x07u
#define Excite_Drive_RES_FEEDBACK_MAX       0x07u

/* Constants for SetCapFB function */
#define Excite_Drive_CAP_FEEDBACK_NONE      0x00u
#define Excite_Drive_CAP_FEEDBACK_1_3PF     0x01u
#define Excite_Drive_CAP_FEEDBACK_3_3PF     0x02u
#define Excite_Drive_CAP_FEEDBACK_4_6PF     0x03u
#define Excite_Drive_CAP_FEEDBACK_MAX       0x03u

/***************************************
*              Registers        
***************************************/

#define Excite_Drive_CR0    (* (reg8 *) Excite_Drive_SC__CR0 )
#define Excite_Drive_CR1    (* (reg8 *) Excite_Drive_SC__CR1 )
#define Excite_Drive_CR2    (* (reg8 *) Excite_Drive_SC__CR2 )
#define Excite_Drive_PWRMGR (* (reg8 *) Excite_Drive_SC__PM_ACT_CFG )   /* Power manager */
#define Excite_Drive_BSTCLK (* (reg8 *) Excite_Drive_SC__BST )          /* SC Boost Clk Control */

/* CR0 SC/CT Control Register 0 definitions */

/* Bit Field SC_MODE_ENUM - SCxx_CR0[3:1], TIA Mode = 3b'001' */
#define Excite_Drive_MODE_TIA      (0x01u << 1) 

/* CR1 SC/CT Control Register 1 definitions */

/* Bit Field  SC_DRIVE_ENUM - SCxx_CR1[1:0] */
#define Excite_Drive_DRIVE_MASK     0x03u
#define Excite_Drive_DRIVE_280UA    0x00u
#define Excite_Drive_DRIVE_420UA    0x01u
#define Excite_Drive_DRIVE_530UA    0x02u
#define Excite_Drive_DRIVE_650UA    0x03u

/* Bit Field  SC_COMP_ENUM - SCxx_CR1[3:2]  */
#define Excite_Drive_COMP_MASK      (0x03u << 2)
#define Excite_Drive_COMP_3P0PF     (0x00u << 2)
#define Excite_Drive_COMP_3P6PF     (0x01u << 2)
#define Excite_Drive_COMP_4P35PF    (0x02u << 2)
#define Excite_Drive_COMP_5P1PF     (0x03u << 2)

/* Bit Field  SC_DIV2_ENUM - SCxx_CR1[4] - n/a for TIA mode */
#define Excite_Drive_DIV2		    (0x01u << 4)
#define Excite_Drive_DIV2_DISABLE   (0x00u << 4)
#define Excite_Drive_DIV2_ENABLE    (0x01u << 4)

/* Bit Field  SC_GAIN_ENUM - SCxx_CR1[5] - n/a for TIA mode] */
#define Excite_Drive_GAIN			(0x01u << 5)
#define Excite_Drive_GAIN_0DB       (0x00u << 5)
#define Excite_Drive_GAIN_6DB       (0x01u << 5)

/* CR2 SC/CT Control Register 2 definitions */

/* Bit Field  SC_BIAS_CONTROL_ENUM - SCxx_CR2[0] */
#define Excite_Drive_BIAS			0x01u
#define Excite_Drive_BIAS_NORMAL    0x00u
#define Excite_Drive_BIAS_LOW       0x01u

/* Bit Field  SC_R20_40B_ENUM - SCxx_CR2[1] - n/a for TIA mode  */
#define Excite_Drive_R20_40B_MASK   (0x01u << 1)
#define Excite_Drive_R20_40B_40K    (0x00u << 1)
#define Excite_Drive_R20_40B_20K    (0x01u << 1)

/* Bit Field  SC_REDC_ENUM  - SCxx_CR2[3:2] */
#define Excite_Drive_REDC_MASK		(0x03u << 2)
#define Excite_Drive_REDC_00        (0x00u << 2)
#define Excite_Drive_REDC_01        (0x02u << 2)
#define Excite_Drive_REDC_10        (0x04u << 2)
#define Excite_Drive_REDC_11        (0x03u << 2)

/* Bit Field  SC_RVAL_ENUM  - SCxx_CR2[6:4]  */
#define Excite_Drive_RVAL_MASK      (0x07u << 4)
#define Excite_Drive_RVAL_20K       (0x00u << 4)
#define Excite_Drive_RVAL_30K       (0x01u << 4)
#define Excite_Drive_RVAL_40K       (0x02u << 4)
#define Excite_Drive_RVAL_60K       (0x03u << 4)
#define Excite_Drive_RVAL_120K      (0x04u << 4)
#define Excite_Drive_RVAL_250K      (0x05u << 4)
#define Excite_Drive_RVAL_500K      (0x06u << 4)
#define Excite_Drive_RVAL_1000K     (0x07u << 4)

/* Bit Field  SC_PGA_GNDVREF_ENUM - SCxx_CR2[7] - n/a for TIA mode   */
#define Excite_Drive_GNDVREF		(0x01u << 7)
#define Excite_Drive_GNDVREF_DI     (0x00u << 7)
#define Excite_Drive_GNDVREF_E      (0x01u << 7)

/* SC Blook Boost Clock Selection Register - Boost Clock Enable  SCxx_BST[3]  */
#define Excite_Drive_BST_CLK_EN		(0x01u << 3)

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define Excite_Drive_ACT_PWR_EN     Excite_Drive_SC__PM_ACT_MSK /* Power enable mask */

#endif /* CY_TIA_Excite_Drive_H */
/* [] END OF FILE */
