/*******************************************************************************
* File Name: IExcite.h  
* Version 1.20
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the 8-bit Current DAC (IDAC8) User Module.
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_IDAC8_IExcite_H)  
#define CY_IDAC8_IExcite_H

/* TODO: Remove this line after changes to DAC */
#define IExcite_FIRST_SILICON 

/***************************************
*        Function Prototypes 
***************************************/

void    IExcite_Start(void);
void    IExcite_Stop(void);
void    IExcite_SetSpeed(uint8 speed);
void    IExcite_SetPolarity(uint8 polarity);
void    IExcite_SetRange(uint8 iRange);
void    IExcite_SetValue(uint8 value);
void    IExcite_DacTrim(void);
  
/***************************************
*       Paramater Initial Values
***************************************/

#define IExcite_DEFAULT_RANGE    0      /* Default DAC range */
#define IExcite_DEFAULT_SPEED    ((2 ? 1:0)*2)  /* Default DAC speed */
#define IExcite_DEFAULT_CNTL     0x00u             /* Default Control */
#define IExcite_DEFAULT_STRB     0    /* Default Strobe mode */
#define IExcite_DEFAULT_DATA     0  /* Initial DAC value */
#define IExcite_DEFAULT_POLARITY 0       /* Default Sink or Source */
#define IExcite_DEFAULT_DATA_SRC 0    /* Default Data Source */

/***************************************
*              API Constants        
***************************************/

/* SetRange constants */

#define IExcite_RANGE_32uA     0x00u
#define IExcite_RANGE_255uA    0x04u
#define IExcite_RANGE_2mA      0x08u

/* SetPolarity constants */
#define IExcite_SOURCE         0x00u
#define IExcite_SINK           0x04u

/* Power setting for SetSpeed API  */
#define IExcite_LOWSPEED       0x00u
#define IExcite_HIGHSPEED      0x02u


/***************************************
*              Registers        
***************************************/

#define IExcite_CR0    (* (reg8 *) IExcite_viDAC8__CR0 )
#define IExcite_CR1    (* (reg8 *) IExcite_viDAC8__CR1 )
#define IExcite_Data   (* (reg8 *) IExcite_viDAC8__D )
#define IExcite_Strobe (* (reg8 *) IExcite_viDAC8__STROBE )
#define IExcite_SW0    (* (reg8 *) IExcite_viDAC8__SW0 )
#define IExcite_SW2    (* (reg8 *) IExcite_viDAC8__SW2 )
#define IExcite_SW3    (* (reg8 *) IExcite_viDAC8__SW3 )
#define IExcite_SW4    (* (reg8 *) IExcite_viDAC8__SW4 )
#define IExcite_TR     (* (reg8 *) IExcite_viDAC8__TR )
#define IExcite_PWRMGR (* (reg8 *) IExcite_viDAC8__PM_ACT_CFG )  /* Power manager */

/***************************************
*              Trim    
*
* Note - VIDAC trim values are stored in the "Customer Table" area in 
* Row 1 of the Hidden Flash.  There are 8 bytes of trim data for each VIDAC block.
* The values are:
*       I Gain offset, min range, Sourcing
*       I Gain offset, min range, Sinking
*       I Gain offset, med range, Sourcing
*       I Gain offset, med range, Sinking
*       I Gain offset, max range, Sourcing
*       I Gain offset, max range, Sinking
*       V Gain offset, 1V range
*       V Gain offset, 4V range
*
* The data set for the 4 VIDACs are arranged using a left side/right side approach:
*   Left 0, Left 1, Right 0, Right 1.
* When mapped to the VIDAC0 thru VIDAC3 as:
*   VIDAC 0, VIDAC 2, VIDAC 1, VIDAC 3
***************************************/

#define IExcite_DAC_POS  (IExcite_viDAC8__D - CYDEV_ANAIF_WRK_DAC0_BASE)

/* DAC offset address from CYDEV_FLSHID_BASE */
#define IExcite_DAC0_OFFSET 0x00011Cu
#define IExcite_DAC1_OFFSET 0x000112u
#define IExcite_DAC2_OFFSET 0x000124u
#define IExcite_DAC3_OFFSET 0x000134u

/* Trim base address for DACs at position 0, 1, 2 and 3 */
#if(IExcite_DAC_POS == 0)
#define IExcite_DAC_TRIM_BASE   CYDEV_FLSHID_BASE + IExcite_DAC0_OFFSET
#endif

#if(IExcite_DAC_POS == 1)
#define IExcite_DAC_TRIM_BASE   CYDEV_FLSHID_BASE + IExcite_DAC1_OFFSET
#endif

#if(IExcite_DAC_POS == 2)
#define IExcite_DAC_TRIM_BASE   CYDEV_FLSHID_BASE + IExcite_DAC2_OFFSET
#endif

#if(IExcite_DAC_POS == 3)
#define IExcite_DAC_TRIM_BASE   CYDEV_FLSHID_BASE + IExcite_DAC3_OFFSET
#endif


/***************************************
*              Register Constants       
***************************************/

/* CR0 iDAC Control Register 0 definitions */  

/* Bit Field  DAC_HS_MODE                  */
#define IExcite_HS_MASK        0x02u
#define IExcite_HS_LOWPOWER    0x00u
#define IExcite_HS_HIGHSPEED   0x02u

/* Bit Field  DAC_MODE                  */
#define IExcite_MODE_MASK      0x10u
#define IExcite_MODE_V         0x00u
#define IExcite_MODE_I         0x10u

/* Bit Field  DAC_RANGE                  */
#define IExcite_RANGE_MASK     0x0Cu
#define IExcite_RANGE_0        0x00u
#define IExcite_RANGE_1        0x04u
#define IExcite_RANGE_2        0x08u
#define IExcite_RANGE_3        0x0Cu

/* CR1 iDAC Control Register 1 definitions */

/* Bit Field  DAC_MX_DATA                  */
#define IExcite_SRC_MASK       0x20u
#define IExcite_SRC_REG        0x00u
#define IExcite_SRC_UDB        0x20u

/* This bit enable reset from UDB array      */
#define IExcite_RESET_MASK     0x10u
#define IExcite_RESET_ENABLE   0x10u
#define IExcite_RESET_DISABLE  0x00u

/* Bit Field  DAC_MX_IDIR_SRC              */
#define IExcite_IDIR_SRC_MASK  0x08u
#define IExcite_IDIR_SRC_REG   0x00u
#define IExcite_IDIR_SRC_UDB   0x08u

/* Bit Field  DAC_I_DIR                  */
/* Register control of current direction      */
#define IExcite_IDIR_MASK      0x04u   
#define IExcite_IDIR_SRC       0x00u
#define IExcite_IDIR_SINK      0x04u

/* Bit Field  DAC_MX_IOFF_SRC                  */
/* Selects source of IOFF control, reg or UDB  */
#define IExcite_IDIR_CTL_MASK  0x02u
#define IExcite_IDIR_CTL_REG   0x00u
#define IExcite_IDIR_CTL_UDB   0x02u

/* Bit Field  DAC_MX_IOFF                   */
/* Register control of IDAC                 */
/* Only valid if IOFF CTL is set to Reg     */
#define IExcite_I_OFF_MASK     0x01u   
#define IExcite_I_OFF          0x00u
#define IExcite_I_ON           0x01u

/* This bit enables data from DAC bus      */
#define IExcite_DACBUS_MASK     0x20u
#define IExcite_DACBUS_ENABLE   0x20u
#define IExcite_DACBUS_DISABLE  0x00u

/* DAC STROBE Strobe Control Register definitions */

/* Bit Field  DAC_MX_STROBE                  */
#define IExcite_STRB_MASK      0x08u
#define IExcite_STRB_EN        0x08u
#define IExcite_STRB_DIS       0x00u

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#if !defined(IExcite_FIRST_SILICON)
#define IExcite_ACT_PWR_EN   IExcite_viDAC8__PM_ACT_MSK /* Power enable mask */ 
#else
#define IExcite_ACT_PWR_EN   0xFF /* TODO: Work around for incorrect power enable */
#endif

#endif /* CY_IDAC8_IExcite_H  */
/*  [] END OF FILE  */
