/*******************************************************************************
* File Name: Mixer.h  
* Version 1.80
*
* Description:
*  This file contains the function prototypes and constants used in
*  the Mixer component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_MIXER_Mixer_H) 
#define CY_MIXER_Mixer_H 

#include "cytypes.h"
#include "cyfitter.h"


/* Check to see if required defines such as CY_PSOC3 and CY_PSOC5 are 
   available */
/* They are defined starting with cy_boot v2.30 */
#ifndef CY_PSOC3
#error Component Mixer_v1_80 requires cy_boot v2.30 or later
#endif /* CY_PSOC3 */


/***************************************
*   Data Struct Definition
***************************************/

/* Low power Mode API Support */
typedef struct _Mixer_backupStruct
{
    uint8   enableState;
}   Mixer_BACKUP_STRUCT;

#if (CY_PSOC5_ES1)
    /* Stop API changes for PSoC5 */
    typedef struct _Mixer_lowPowerBackupStruct
    {
        uint8 CR1_REG;
        uint8 CR2_REG;
    }   Mixer_LOWPOWER_BACKUP_STRUCT;
#endif /* CY_PSOC5_ES1 */


/***************************************
*        Function Prototypes 
***************************************/

void Mixer_Start(void);
void Mixer_Stop(void) ;
void Mixer_SetPower(uint8 power) ;
void Mixer_Sleep(void);
void Mixer_Wakeup(void) ;
void Mixer_SaveConfig(void);
void Mixer_RestoreConfig(void);
void Mixer_Init(void) ;
void Mixer_Enable(void) ;


/***************************************
*              Constants        
***************************************/

/* Component's enable/disable state */
#define Mixer_ENABLED                (0x01u)
#define Mixer_DISABLED               (0x00u)

/* Constants for Mixer Type */
#define Mixer_CTMIXER                (0x00u)
#define Mixer_DTMIXER                (0x01u)

/* Constants for Local Oscillator Freq */
#define Mixer_LO_CLOCK_FREQ_100_KHz  (100)
#define Mixer_UNKNOWN_EXTERNAL_LO    (-1)

/* Constants for SetPower function */
#define Mixer_MINPOWER               (0x00u)
#define Mixer_LOWPOWER               (0x01u)
#define Mixer_MEDPOWER               (0x02u)
#define Mixer_HIGHPOWER              (0x03u)

/* Constants for LO Source */
#define Mixer_LO_SOURCE_INTERNAL     (0x00u)
#define Mixer_LO_SOURCE_EXTERNAL     (0x01u)

/* Constant for VDDA Threshold */
#define Mixer_CYDEV_VDDA_MV          (CYDEV_VDDA_MV)
#define Mixer_VDDA_THRESHOLD_MV      (3500u)

/* Constant for Minimum VDDA Threshold */
#define Mixer_MINIMUM_VDDA_THRESHOLD_MV   (2700u)


/***************************************
*       Initial Paramater Values
***************************************/

#define Mixer_MIXER_TYPE             (0u)
#define Mixer_INIT_POWER             (3u)
#define Mixer_LO_SOURCE              (1u)
#define Mixer_EXTERNAL_LO_CLK_FREQ   (-1)
#define Mixer_VddaVal                (5.5)

#if (Mixer_LO_SOURCE == Mixer_LO_SOURCE_INTERNAL)
    /* Internal LO clock frequency */
    #define Mixer_LO_CLOCK_FREQ      (1000)
#else
    #define Mixer_LO_CLOCK_FREQ      ((-1 == Mixer_UNKNOWN_EXTERNAL_LO) ? (1000) : (-1))
#endif /* Mixer_LO_SOURCE == Mixer_LO_SOURCE_INTERNAL */


/***************************************
*              Registers        
***************************************/

/* SC Block Configuration Registers */
#define Mixer_CR0_REG                (* (reg8 *) Mixer_SC__CR0 )
#define Mixer_CR0_PTR                (  (reg8 *) Mixer_SC__CR0 )
#define Mixer_CR1_REG                (* (reg8 *) Mixer_SC__CR1 )
#define Mixer_CR1_PTR                (  (reg8 *) Mixer_SC__CR1 )
#define Mixer_CR2_REG                (* (reg8 *) Mixer_SC__CR2 )
#define Mixer_CR2_PTR                (  (reg8 *) Mixer_SC__CR2 )
/* SC Block clk control */
#define Mixer_CLK_REG                (* (reg8 *) Mixer_SC__CLK )  
#define Mixer_CLK_PTR                (  (reg8 *) Mixer_SC__CLK )
/* SC Boost clk Control */
#define Mixer_BSTCLK_REG             (* (reg8 *) Mixer_SC__BST )  
#define Mixer_BSTCLK_PTR             (  (reg8 *) Mixer_SC__BST )
/* Power manager */
#define Mixer_PM_ACT_CFG_REG         (* (reg8 *) Mixer_SC__PM_ACT_CFG )  
#define Mixer_PM_ACT_CFG_PTR         (  (reg8 *) Mixer_SC__PM_ACT_CFG )
/* Power manager */
#define Mixer_PM_STBY_CFG_REG        (* (reg8 *) Mixer_SC__PM_STBY_CFG )  
#define Mixer_PM_STBY_CFG_PTR        (  (reg8 *) Mixer_SC__PM_STBY_CFG )

/* Pump clock selectin register */
#define Mixer_PUMP_CR1_REG           (* (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)   
#define Mixer_PUMP_CR1_PTR           (  (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)

/* Pump Register for SC block */
#define Mixer_SC_MISC_REG            (* (reg8 *) CYDEV_ANAIF_RT_SC_MISC)
#define Mixer_SC_MISC_PTR            (  (reg8 *) CYDEV_ANAIF_RT_SC_MISC)

/* PM_ACT_CFG (Active Power Mode CFG Register) mask */ 
/* Power enable mask */
#define Mixer_ACT_PWR_EN             Mixer_SC__PM_ACT_MSK 

/* PM_STBY_CFG (Alternative Active Power Mode CFG Register) mask */ 
/* Power enable mask */
#define Mixer_STBY_PWR_EN             Mixer_SC__PM_STBY_MSK 

/* LO oscillator clock register defines */
#if(Mixer_LO_SOURCE == Mixer_LO_SOURCE_INTERNAL)
    #define Mixer_PWRMGR_ACLK_REG       (* (reg8 *) Mixer_aclk__PM_ACT_CFG ) 
    #define Mixer_PWRMGR_ACLK_PTR       (  (reg8 *) Mixer_aclk__PM_ACT_CFG ) 

    #define Mixer_STBY_PWRMGR_ACLK_REG  (* (reg8 *) Mixer_aclk__PM_STBY_CFG )
    #define Mixer_STBY_PWRMGR_ACLK_PTR  (  (reg8 *) Mixer_aclk__PM_STBY_CFG )
#endif /* Mixer_LO_SOURCE == Mixer_LO_SOURCE_INTERNAL */

/* Below defines are to retain backward compatibility. These are depricated 
   and should not be used in future designs */

/* SC Block Configuration Registers */
#define Mixer_CR0                    Mixer_CR0_REG
#define Mixer_CR1                    Mixer_CR1_REG
#define Mixer_CR2                    Mixer_CR2_REG
/* SC Block clk control */
#define Mixer_CLK                    Mixer_CLK_REG     
/* SC Boost clk Control */
#define Mixer_BSTCLK                 Mixer_BSTCLK_REG  
/* Power manager */
#define Mixer_PM_ACT_CFG             Mixer_PM_ACT_CFG_REG  
/* Power manager */
#define Mixer_PM_STBY_CFG            Mixer_PM_STBY_CFG_REG  

/* Pump clock selectin register */
#define Mixer_PUMP_CR1               Mixer_PUMP_CR1_REG   

/* Pump Register for SC block */
#define Mixer_SC_MISC                Mixer_SC_MISC_REG


/***************************************
*        Register Constants        
***************************************/

/* ANIF.PUMP.CR1 Constants */
#define Mixer_PUMP_CR1_SC_CLKSEL     (0x80u)

/* SC_MISC constants */
#define Mixer_PUMP_FORCE             (0x20u)
#define Mixer_PUMP_AUTO              (0x10u)
#define Mixer_DIFF_PGA_1_3           (0x02u)
#define Mixer_DIFF_PGA_0_2           (0x01u)

/* CR0 SC Block Control Register 0 definitions */

/* Bit Field SC_MODE_ENUM - SCxx_CR0[3:1] */
#define Mixer_MODE_CTMIXER           (0x02u << 1)
#define Mixer_MODE_DTMIXER           (0x03u << 1)

/* CR1 SC Block Control Register 1 definitions */

/* Bit Field  SC_DRIVE_ENUM - SCxx_CR1[1:0] */
#define Mixer_DRIVE_MASK             (0x03u)
#define Mixer_DRIVE_280UA            (0x00u)
#define Mixer_DRIVE_420UA            (0x01u)
#define Mixer_DRIVE_530UA            (0x02u)
#define Mixer_DRIVE_650UA            (0x03u)

/* Bit Field  SC_COMP_ENUM - SCxx_CR1[3:2] */
#define Mixer_COMP_MASK              (0x03u << 2)
#define Mixer_COMP_3P0PF             (0x00u << 2)
#define Mixer_COMP_3P6PF             (0x01u << 2)
#define Mixer_COMP_4P35PF            (0x02u << 2)
#define Mixer_COMP_5P1PF             (0x03u << 2)

/* Bit Field  SC_DIV2_ENUM - SCxx_CR1[4] */
#define Mixer_DIV2                   (0x01u << 4)
#define Mixer_DIV2_DISABLE           (0x00u << 4)
#define Mixer_DIV2_ENABLE            (0x01u << 4)

/* Bit Field  SC_GAIN_ENUM - SCxx_CR1[5] */
#define Mixer_GAIN                   (0x01u << 5)
#define Mixer_GAIN_0DB               (0x00u << 5)
#define Mixer_GAIN_6DB               (0x01u << 5)

/* CR2 SC Block Control Register 2 definitions */

/* Bit Field  SC_BIAS_CONTROL_ENUM - SCxx_CR2[0] */
#define Mixer_BIAS                   (0x01u)
#define Mixer_BIAS_NORMAL            (0x00u)
#define Mixer_BIAS_LOW               (0x01u)

/* Bit Field  SC_R20_40B_ENUM - SCxx_CR2[1] */
#define Mixer_R20_40B                (0x01u << 1)
#define Mixer_R20_40B_40K            (0x00u << 1)
#define Mixer_R20_40B_20K            (0x01u << 1)

/* Bit Field  SC_REDC_ENUM  - SCxx_CR2[3:2] */
#define Mixer_REDC_MASK              (0x03u << 2)
#define Mixer_REDC_00                (0x00u << 2)
#define Mixer_REDC_01                (0x01u << 2)
#define Mixer_REDC_10                (0x02u << 2)
#define Mixer_REDC_11                (0x03u << 2)

/* Bit Field  SC_RVAL_ENUM  - SCxx_CR2[6:4] */
#define Mixer_RVAL_MASK              (0x07u << 4)
#define Mixer_RVAL_20K               (0x00u << 4)
#define Mixer_RVAL_30K               (0x01u << 4)
#define Mixer_RVAL_40K               (0x02u << 4)
#define Mixer_RVAL_80K               (0x03u << 4)
#define Mixer_RVAL_120K              (0x04u << 4)
#define Mixer_RVAL_250K              (0x05u << 4)
#define Mixer_RVAL_500K              (0x06u << 4)
#define Mixer_RVAL_1000K             (0x07u << 4)

/* Bit Field  SC_PGA_GNDVREF_ENUM - SCxx_CR2[7] */
#define Mixer_GNDVREF                (0x01u << 7)
#define Mixer_GNDVREF_DI             (0x00u << 7)
#define Mixer_GNDVREF_E              (0x01u << 7) 

/* SC Block Clock Control SCx.CLk */
#define Mixer_DYN_CNTL_EN            (0x01u << 5)
#define Mixer_BYPASS_SYNC            (0x01u << 4)
#define Mixer_CLK_EN                 (0x01u << 3)

/* SC Block Boost Clock Selection Register - Boost Clock Enable  SCxx_BST[3]  */
#define Mixer_BST_CLK_EN             (0x01u << 3)

/* internal LO oscillator Clock enable */
#if(Mixer_LO_SOURCE == Mixer_LO_SOURCE_INTERNAL)
    #define Mixer_ACT_PWR_ACLK_EN    Mixer_aclk__PM_ACT_MSK 
    #define Mixer_STBY_PWR_ACLK_EN   Mixer_aclk__PM_STBY_MSK 
#endif /* Mixer_LO_SOURCE == Mixer_LO_SOURCE_INTERNAL */

#endif /* CY_MIXER_Mixer_H */


/* [] END OF FILE */
