/*******************************************************************************
* File Name: Mixer_1.h  
* Version 1.10
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the Mixer User Module.
*
*   Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_MIXER_Mixer_1_H) 
#define CY_MIXER_Mixer_1_H 

/***************************************
*        Function Prototypes 
***************************************/
void    Mixer_1_Start(void);
void    Mixer_1_Stop(void);
void    Mixer_1_SetPower(uint8 power);


/***************************************
*       Initial Paramater Values
***************************************/
#define Mixer_1_MIXER_TYPE         1
#define Mixer_1_INIT_POWER         2
#define Mixer_1_LO_FREQ_FLAG       0      
#define Mixer_1_MIN_VDDA           0


/***************************************
*              Constants        
***************************************/

/* Constants for Mixer Type */
#define Mixer_1_CTMIXER                0x00u
#define Mixer_1_DTMIXER                0x01u

/* Constants for Local Oscillator Freq */
#define Mixer_1_LO_LT_100K             0x00u
#define Mixer_1_LO_GTE_100K            0x01u

/* Constants for Minimum Vdda paramater */
#define  Mixer_1_MIN_VDDA_GTE_2_7V     0x00u
#define  Mixer_1_MIN_VDDA_LT_2_7V      0x01u

/* Constants for SetPower function */
#define Mixer_1_MINPOWER               0x00u
#define Mixer_1_LOWPOWER               0x01u
#define Mixer_1_MEDPOWER               0x02u
#define Mixer_1_HIGHPOWER              0x03u


/***************************************
*              Registers        
***************************************/

/* SC Block Configuration Registers */
#define Mixer_1_CR0    (* (reg8 *) Mixer_1_SC__CR0 )
#define Mixer_1_CR1    (* (reg8 *) Mixer_1_SC__CR1 )
#define Mixer_1_CR2    (* (reg8 *) Mixer_1_SC__CR2 )

#define Mixer_1_CLK    (* (reg8 *) Mixer_1_SC__CLK )          /* SC Block clk control */
#define Mixer_1_BSTCLK (* (reg8 *) Mixer_1_SC__BST )          /* SC Boost clk Control */
#define Mixer_1_PWRMGR (* (reg8 *) Mixer_1_SC__PM_ACT_CFG )   /* Power manager */

/* CR0 SC Block Control Register 0 definitions */

/* Bit Field SC_MODE_ENUM - SCxx_CR0[3:1] */
#define Mixer_1_MODE_CTMIXER   (0x02u << 1)
#define Mixer_1_MODE_DTMIXER   (0x03u << 1)

/* CR1 SC Block Control Register 1 definitions */

/* Bit Field  SC_DRIVE_ENUM - SCxx_CR1[1:0] */
#define Mixer_1_DRIVE_MASK     0x03u
#define Mixer_1_DRIVE_280UA    0x00u
#define Mixer_1_DRIVE_420UA    0x01u
#define Mixer_1_DRIVE_530UA    0x02u
#define Mixer_1_DRIVE_650UA    0x03u

/* Bit Field  SC_COMP_ENUM - SCxx_CR1[3:2]  */
#define Mixer_1_COMP_MASK      (0x03u << 2)
#define Mixer_1_COMP_3P0PF     (0x00u << 2)
#define Mixer_1_COMP_3P6PF     (0x01u << 2)
#define Mixer_1_COMP_4P35PF    (0x02u << 2)
#define Mixer_1_COMP_5P1PF     (0x03u << 2)

/* Bit Field  SC_DIV2_ENUM - SCxx_CR1[4] */
#define Mixer_1_DIV2           (0x01u << 4)
#define Mixer_1_DIV2_DISABLE   (0x00u << 4)
#define Mixer_1_DIV2_ENABLE    (0x01u << 4)

/* Bit Field  SC_GAIN_ENUM - SCxx_CR1[5] */
#define Mixer_1_GAIN           (0x01u << 5)
#define Mixer_1_GAIN_0DB       (0x00u << 5)
#define Mixer_1_GAIN_6DB       (0x01u << 5)

/* CR2 SC Block Control Register 2 definitions */

/* Bit Field  SC_BIAS_CONTROL_ENUM - SCxx_CR2[0] */
#define Mixer_1_BIAS           0x01u
#define Mixer_1_BIAS_NORMAL    0x00u
#define Mixer_1_BIAS_LOW       0x01u

/* Bit Field  SC_R20_40B_ENUM - SCxx_CR2[1]  */
#define Mixer_1_R20_40B        (0x01u << 1)
#define Mixer_1_R20_40B_40K    (0x00u << 1)
#define Mixer_1_R20_40B_20K    (0x01u << 1)

/* Bit Field  SC_REDC_ENUM  - SCxx_CR2[3:2] */
#define Mixer_1_REDC_MASK      (0x03u << 2)
#define Mixer_1_REDC_00        (0x00u << 2)
#define Mixer_1_REDC_01        (0x01u << 2)
#define Mixer_1_REDC_10        (0x02u << 2)
#define Mixer_1_REDC_11        (0x03u << 2)

/* Bit Field  SC_RVAL_ENUM  - SCxx_CR2[6:4]  */
#define Mixer_1_RVAL_MASK      (0x07u << 4)
#define Mixer_1_RVAL_20K       (0x00u << 4)
#define Mixer_1_RVAL_30K       (0x01u << 4)
#define Mixer_1_RVAL_40K       (0x02u << 4)
#define Mixer_1_RVAL_80K       (0x03u << 4)
#define Mixer_1_RVAL_120K      (0x04u << 4)
#define Mixer_1_RVAL_250K      (0x05u << 4)
#define Mixer_1_RVAL_500K      (0x06u << 4)
#define Mixer_1_RVAL_1000K     (0x07u << 4)

/* Bit Field  SC_PGA_GNDVREF_ENUM - SCxx_CR2[7]  */
#define Mixer_1_GNDVREF        (0x01u << 7)
#define Mixer_1_GNDVREF_DI     (0x00u << 7)
#define Mixer_1_GNDVREF_E      (0x01u << 7)

/* SC Block Clock Control SCx.CLk */
#define Mixer_1_DYN_CNTL_EN     (0x01u << 5)
#define Mixer_1_BYPASS_SYNC     (0x01u << 4)
#define Mixer_1_CLK_EN          (0x01u << 3)

/* SC Block Boost Clock Selection Register - Boost Clock Enable  SCxx_BST[3]  */
#define Mixer_1_BST_CLK_EN     (0x01u << 3)

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define Mixer_1_ACT_PWR_EN     Mixer_1_SC__PM_ACT_MSK /* Power enable mask */

#endif /* CY_MIXER_Mixer_1_H */


/* [] END OF FILE */
