/*******************************************************************************
* File Name: Mixer_Buffer_PM.c  
* Version 1.70
*
* Description:
*  This file provides the power manager source code to the API for the PGA 
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Mixer_Buffer.h"

static Mixer_Buffer_BACKUP_STRUCT  Mixer_Buffer_backup;


/*******************************************************************************
* Function Name: Mixer_Buffer_SaveConfig
********************************************************************************
*
* Summary:
*  Save the current user register configuration.
* 
* Parameters:
*  void
* 
* Return:
*  void
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Mixer_Buffer_SaveConfig(void)
{
    /* Nothing to save as registers are System reset on retention flops */
}


/*******************************************************************************  
* Function Name: Mixer_Buffer_RestoreConfig
********************************************************************************
*
* Summary:
*  Restore the register configurations.
* 
* Parameters:
*  void
* 
* Return:
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_Buffer_RestoreConfig(void)
{
    /* Nothing to restore */
}


/*******************************************************************************   
* Function Name: Mixer_Buffer_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  Mixer_Buffer_backup:  The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_Buffer_Sleep(void)
{
    /* Save PGA enable state */
    if(Mixer_Buffer_ACT_PWR_EN == (Mixer_Buffer_PM_ACT_CFG_REG & Mixer_Buffer_ACT_PWR_EN))
    {
        /* Component is enabled */
        Mixer_Buffer_backup.enableState = 1u;
    }
    else
    {
        /* Component is disabled */
        Mixer_Buffer_backup.enableState = 0u;
    }

    /* Stop the configuration */
    Mixer_Buffer_Stop();

    /* Save the configuration */
    Mixer_Buffer_SaveConfig();
}


/*******************************************************************************
* Function Name: Mixer_Buffer_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  void
*
* Global variables:
*  Mixer_Buffer_backup:  The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
*
* Reentrant:
*  No
* 
*******************************************************************************/
void Mixer_Buffer_Wakeup(void) 
{
    /* Restore the configurations */
    Mixer_Buffer_RestoreConfig();

     /* Enable's the component operation */
    if(Mixer_Buffer_backup.enableState == 1u)
    {
        Mixer_Buffer_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
