/*******************************************************************************
* File Name: Mixer_Bypass_Mux.c  
* Version 1.10
*
*  Description:
*    This file contains all functions required for the analog multiplexer
*    AMux User Module.
*
*   Note:
*
*******************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "Mixer_Bypass_Mux.h"
#include "cyfitter_cfg.h"

uint8 Mixer_Bypass_Mux_lastChannel = Mixer_Bypass_Mux_NULL_CHANNEL; 

/*******************************************************************************
* Function Name: Mixer_Bypass_Mux_Start
********************************************************************************
* Summary:
*  This function resets all connections, to disconnected.
*
* Parameters:  
*  (void)
*
* Return: 
*  (void) 
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Mixer_Bypass_Mux_Start(void) 
{
   Mixer_Bypass_Mux_DisconnectAll(); 
}


/*******************************************************************************
* Function Name: Mixer_Bypass_Mux_Stop
********************************************************************************
* Summary:
*  This function disconnects all connections.
*
* Parameters:  
*  (void)
*
* Return: 
*  (void) 
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Mixer_Bypass_Mux_Stop(void) 
{
   Mixer_Bypass_Mux_DisconnectAll(); 
}



/*******************************************************************************
* Function Name: Mixer_Bypass_Mux_Select
********************************************************************************
* Summary:
*  This functions first disconnects all channels then connects the selected
*  channel "channel".
*
* Parameters:  
*  channel:  (uint8) Selects the channel in which to perform the operation.
*
* Return: 
*  (void) Description of return value, if there is a return value.
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Mixer_Bypass_Mux_Select(uint8 channel) 
{
   Mixer_Bypass_Mux_DisconnectAll();        /* Disconnect all previous connections */
   Mixer_Bypass_Mux_Connect(channel);       /* Make the given selection */
   Mixer_Bypass_Mux_lastChannel = channel;  /* Update last channel */
}

/*******************************************************************************
* Function Name: Mixer_Bypass_Mux_FastSelect
********************************************************************************
* Summary:
*  This functions first disconnects just the last channel then connects the
*  given channel.
*
* Parameters:  
*  channel:  (uint8) Selects the channel in which to connect.
*
* Return: 
*  None
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Mixer_Bypass_Mux_FastSelect(uint8 channel) 
{
   /* Disconnect the last valid channel */
   if( Mixer_Bypass_Mux_lastChannel != Mixer_Bypass_Mux_NULL_CHANNEL)   /* Update last channel */
   {
      Mixer_Bypass_Mux_Disconnect(Mixer_Bypass_Mux_lastChannel);
   }

   /* Make the new channel connection */
   Mixer_Bypass_Mux_Connect(channel);
   Mixer_Bypass_Mux_lastChannel = channel;   /* Update last channel */
}

#if(Mixer_Bypass_Mux_MUXTYPE == Mixer_Bypass_Mux_MUX_DIFF)
/*******************************************************************************
* Function Name: Mixer_Bypass_Mux_Connect
********************************************************************************
* Summary:
*  This function connects the given channel, but does not affect any other
*  previous connection.
*
* Parameters:  
*  channel:  (uint8) Selects the channel in which to connect.
*
* Return: 
*  (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Mixer_Bypass_Mux_Connect(uint8 channel) 
{
   Mixer_Bypass_Mux_CYAMUXSIDE_A_Set(channel);
   Mixer_Bypass_Mux_CYAMUXSIDE_B_Set(channel);
}
#endif

#if(Mixer_Bypass_Mux_MUXTYPE == Mixer_Bypass_Mux_MUX_DIFF)
/*******************************************************************************
* Function Name: Mixer_Bypass_Mux_Disconnect
********************************************************************************
* Summary:
*  This function disconnects the given channel from the common or output.  It
*  does not affect any other connection.
*
* Parameters:  
*  channel:  (uint8) Selects the channel in which to disconnect.
*
* Return: 
*  (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Mixer_Bypass_Mux_Disconnect(uint8 channel) 
{
   Mixer_Bypass_Mux_CYAMUXSIDE_A_Unset(channel);
   Mixer_Bypass_Mux_CYAMUXSIDE_B_Unset(channel);
}
#endif

/*******************************************************************************
* Function Name: Mixer_Bypass_Mux_DisconnectAll
********************************************************************************
* Summary:
*  This function disconnects all channels.
*
* Parameters:  
*  (void)
*
* Return: 
*  (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Mixer_Bypass_Mux_DisconnectAll(void) 
{
   uint8 chan;

   #if(Mixer_Bypass_Mux_MUXTYPE == Mixer_Bypass_Mux_MUX_SINGLE)
      for(chan = 0; chan < Mixer_Bypass_Mux_CHANNELS ; chan++)
      {
         Mixer_Bypass_Mux_Unset(chan);
      }
   #else
      for(chan = 0; chan < Mixer_Bypass_Mux_CHANNELS ; chan++)
      {
         Mixer_Bypass_Mux_CYAMUXSIDE_A_Unset(chan);
         Mixer_Bypass_Mux_CYAMUXSIDE_B_Unset(chan);
      }
   #endif
}


/* [] END OF FILE */
