/*******************************************************************************
* File Name: Mixer_PM.c  
* Version 1.80
*
* Description:
*  This file provides the power manager source code to the API for 
*  the MIXER component.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Mixer.h"

static Mixer_BACKUP_STRUCT  Mixer_backup =
{
    Mixer_DISABLED
};


/*******************************************************************************
* Function Name: Mixer_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*  
* Parameters:  
*  void.
*
* Return: 
*  void.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_SaveConfig(void)
{
    /* Nothing to save before entering into sleep mode as all the registers used 
       here are retension registers. */
}


/*******************************************************************************
* Function Name: Mixer_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void.
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_RestoreConfig(void)
{
    /* Nothing to restore */
}


/*******************************************************************************
* Function Name: Mixer_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  Mixer_backup:  The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_Sleep(void)
{
    /* Save TIA enable state */
    if(Mixer_ACT_PWR_EN == (Mixer_PM_ACT_CFG_REG & Mixer_ACT_PWR_EN))
    {
        /* Component is enabled */
        Mixer_backup.enableState = Mixer_ENABLED;
    }
    else
    {
        /* Component is disabled */
        Mixer_backup.enableState = Mixer_DISABLED;
    }

    /* Stop the configuration */
    Mixer_Stop();

    /* Saves the user configuration */
    Mixer_SaveConfig();
}


/*******************************************************************************
* Function Name: Mixer_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  void
*
* Global variables:
*  Mixer_backup:  The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_Wakeup(void) 
{
    /* Restore the user configuration */
    Mixer_RestoreConfig();
    
    /* Enable's the component operation */
    if(Mixer_backup.enableState == Mixer_ENABLED)
    {
        Mixer_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
