/*******************************************************************************
* File Name: OpAmp_1.c
* Version 1.10
*
* Description:
*   This file provides the source code to the API for the OpAmp (Analog Buffer) 
*   User Module.
*
* NOTE:
* 
*
*******************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "OpAmp_1.h"

uint8  OpAmp_1_initVar = 0;

/*******************************************************************************
* Funciton Name:   OpAmp_1_Start
********************************************************************************
*
* Summary:
*  The start function initializes the Analog Buffer with the default values, and 
*  sets the power to the given level.  A power level of 0, is the same as 
*  executing the stop function.
*
* Parameters: 
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void OpAmp_1_Start(void) 
{
   if(OpAmp_1_initVar == 0)
   {
      OpAmp_1_initVar = 1;
      OpAmp_1_SetPower(OpAmp_1_DEFAULT_POWER);

      /* Set follower mode if selected */
      OpAmp_1_SW |= OpAmp_1_DEFAULT_MODE;
   }

   /* Enable power to buffer */
   OpAmp_1_PWRMGR |= OpAmp_1_ACT_PWR_EN;

}

/*******************************************************************************
* Function Name: OpAmp_1_Stop
********************************************************************************
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:  
*   (void)
*
* Return:  
*   (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void OpAmp_1_Stop(void)
{
   /* Disable power to buffer */
   OpAmp_1_PWRMGR &= ~OpAmp_1_ACT_PWR_EN;
}

/*******************************************************************************
* Funciton Name:   OpAmp_1_SetPower
********************************************************************************
*
* Summary:
*  Sets power level of Analog buffer.
*
* Parameters: 
*    power:   Sets power level between low (1) and high power (3).
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void OpAmp_1_SetPower(uint8 power) 
{
      OpAmp_1_CR &= ~OpAmp_1_PWR_MASK;             /* Clear power setting  */
      OpAmp_1_CR |= ( power & OpAmp_1_PWR_MASK);   /* Set device power     */
}
/* [] END OF FILE */


