/*******************************************************************************
* File Name: OpAmp_1.h  
* Version 1.10
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the OpAmp (Analog Buffer) User Module.
*
*   Note:
*     
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_OPAMP_OpAmp_1_H) 
#define CY_OPAMP_OpAmp_1_H 

/**************************************
*        Function Prototypes 
**************************************/

void    OpAmp_1_Start(void);
void    OpAmp_1_Stop(void);
void    OpAmp_1_SetPower(uint8 power);


/**************************************
*           API Constants        
**************************************/

/* Power constants for SetPower() function */
#define OpAmp_1_LOWPOWER    0x01u
#define OpAmp_1_MEDPOWER    0x02u
#define OpAmp_1_HIGHPOWER   0x03u


/**************************************
*           Parameter Defaults        
**************************************/

#define OpAmp_1_DEFAULT_POWER    3 
#define OpAmp_1_DEFAULT_MODE     1 

/**************************************
*       Register Constants        
**************************************/

/* CX Analog Buffer Input Selection Register */

/* Power mode defines.                  */
#define OpAmp_1_PWR_MASK    0x03u 
#define OpAmp_1_PWR_SLOW    0x01u
#define OpAmp_1_PWR_MEDIUM  0x02u
#define OpAmp_1_PWR_FAST    0x03u

/* MX Analog Buffer Input Selection Register */

/* Bit Field  MX_VN                     */
#define OpAmp_1_MX_VN_MASK  0x30u 
#define OpAmp_1_MX_VN_NC    0x00u 
#define OpAmp_1_MX_VN_AG4   0x20u 
#define OpAmp_1_MX_VN_AG6   0x30u 

/* Bit Field  MX_VP                     */
#define OpAmp_1_MX_VP_MASK  0x0Fu 
#define OpAmp_1_MX_VP_NC    0x00u 
#define OpAmp_1_MX_VP_VREF  0x07u 
#define OpAmp_1_MX_VP_AG4   0x08u 
#define OpAmp_1_MX_VP_AG5   0x09u 
#define OpAmp_1_MX_VP_AG6   0x0Au 
#define OpAmp_1_MX_VP_AG7   0x08u 
#define OpAmp_1_MX_VP_ABUS0 0x0Cu 
#define OpAmp_1_MX_VP_ABUS1 0x0Du 
#define OpAmp_1_MX_VP_ABUS2 0x0Eu 
#define OpAmp_1_MX_VP_ABUS3 0x0Fu 

/* SW Analog Buffer Routing Switch Reg  */

/* Bit Field  SW                        */
#define OpAmp_1_SW_MASK     0x07u 
#define OpAmp_1_SW_SWINP    0x04u  /* Enable positive input */
#define OpAmp_1_SW_SWINN    0x02u  /* Enable negative input */
#define OpAmp_1_SW_SWFOL    0x01u  /* Enable follower mode  */

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define OpAmp_1_ACT_PWR_EN   OpAmp_1_ABuf__PM_ACT_MSK /* Power enable mask */

/**************************************
*             Registers        
**************************************/

#define OpAmp_1_CR    	(* (reg8 *) OpAmp_1_ABuf__CR )
#define OpAmp_1_MX    	(* (reg8 *) OpAmp_1_ABuf__MX )
#define OpAmp_1_SW    	(* (reg8 *) OpAmp_1_ABuf__SW )
#define OpAmp_1_PWRMGR  (* (reg8 *) OpAmp_1_ABuf__PM_ACT_CFG )  /* Power manager */

#endif /* CY_OPAMP_OpAmp_1_H */

/* [] END OF FILE */
