/*******************************************************************************
* File Name: PGA_Inv_1.h  
* Version 1.10
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the PGA_Inv User Module.
*
*   Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_PGA_Inv_PGA_Inv_1_H) 
#define CY_PGA_Inv_PGA_Inv_1_H 

/***************************************
*        Function Prototypes 
***************************************/

void    PGA_Inv_1_Start(void);
void    PGA_Inv_1_Stop(void);
void    PGA_Inv_1_SetPower(uint8 power);
void    PGA_Inv_1_SetGain(uint8 gain);


/***************************************
*       Initialization Values
***************************************/

#define PGA_Inv_1_DEFAULT_GAIN  0
#define PGA_Inv_1_DEFAULT_POWER 2
#define PGA_Inv_1_ACLK_ENABLE   0

/***************************************
*              Constants        
***************************************/

/* Power constants for SetPower function */
#define PGA_Inv_1_MINPOWER   0x00u
#define PGA_Inv_1_LOWPOWER   0x01u
#define PGA_Inv_1_MEDPOWER   0x02u
#define PGA_Inv_1_HIGHPOWER  0x03u

/* Constants for SetGain function */
#define PGA_Inv_1_GAIN_01    0x00u
#define PGA_Inv_1_GAIN_03    0x01u
#define PGA_Inv_1_GAIN_07    0x02u
#define PGA_Inv_1_GAIN_15    0x03u
#define PGA_Inv_1_GAIN_22    0x04u
#define PGA_Inv_1_GAIN_23    0x05u
#define PGA_Inv_1_GAIN_24    0x06u
#define PGA_Inv_1_GAIN_31    0x07u
#define PGA_Inv_1_GAIN_47    0x08u
#define PGA_Inv_1_GAIN_49    0x09u
#define PGA_Inv_1_GAIN_MAX   0x09u




/* CR0 SC/CT Control Register 0 definitions */
#define PGA_Inv_1_MODE_PGA      0x0Cu


/* CR1 SC/CT Control Register 1 definitions */
/* Bit Field  SC_COMP_ENUM                  */
#define PGA_Inv_1_COMP_MASK     0x0Cu
#define PGA_Inv_1_COMP_3P0PF    0x00u
#define PGA_Inv_1_COMP_3P6PF    0x04u
#define PGA_Inv_1_COMP_4P35PF   0x08u
#define PGA_Inv_1_COMP_5P1PF    0x0Cu

/* Bit Field  SC_DIV2_ENUM                  */
#define PGA_Inv_1_DIV2_MASK     0x10u
#define PGA_Inv_1_DIV2_DISABLE  0x00u
#define PGA_Inv_1_DIV2_ENABLE   0x10u

/* Bit Field  SC_DRIVE_ENUM                  */
#define PGA_Inv_1_DRIVE_MASK    0x03u
#define PGA_Inv_1_DRIVE_280UA   0x00u
#define PGA_Inv_1_DRIVE_420UA   0x01u
#define PGA_Inv_1_DRIVE_530UA   0x02u
#define PGA_Inv_1_DRIVE_650UA   0x03u

/* Bit Field  SC_PGA_MODE_ENUM                  */
#define PGA_Inv_1_PGA_MODE_MASK 0x20u
#define PGA_Inv_1_PGA_INV       0x00u
#define PGA_Inv_1_PGA_NINV      0x20u

/* CR2 SC/CT Control Register 2 definitions */


/* Bit Field  SC_BIAS_CONTROL_ENUM             */
#define PGA_Inv_1_BIAS_MASK     0x01u
#define PGA_Inv_1_BIAS_NORMAL   0x00u
#define PGA_Inv_1_BIAS_LOW      0x01u

/* Bit Field  SC_PGA_GNDVREF_ENUM              */
#define PGA_Inv_1_GNDVREF_MASK  0x80u
#define PGA_Inv_1_GNDVREF_DI    0x00u
#define PGA_Inv_1_GNDVREF_E     0x80u

/* Bit Field  SC_R20_40B_ENUM                  */
#define PGA_Inv_1_R20_40B_MASK  0x02u
#define PGA_Inv_1_R20_40B_40K   0x00u
#define PGA_Inv_1_R20_40B_20K   0x02u

/* Bit Field  SC_REDC_ENUM                     */
#define PGA_Inv_1_REDC_MASK          0x0Cu
#define PGA_Inv_1_REDC_00            0x00u
#define PGA_Inv_1_REDC_01            0x04u
#define PGA_Inv_1_REDC_10            0x08u
#define PGA_Inv_1_REDC_11            0x0Cu

/* Bit Field  SC_RVAL_ENUM                     */
#define PGA_Inv_1_RVAL_MASK          0x70u
#define PGA_Inv_1_RVAL_20K           0x00u
#define PGA_Inv_1_RVAL_30K           0x10u
#define PGA_Inv_1_RVAL_40K           0x20u
#define PGA_Inv_1_RVAL_60K           0x30u
#define PGA_Inv_1_RVAL_120K          0x40u
#define PGA_Inv_1_RVAL_250K          0x50u
#define PGA_Inv_1_RVAL_500K          0x60u
#define PGA_Inv_1_RVAL_1000K         0x70u

/* Bit Field  PGA_INVERTING_GAIN_ENUM    */
#define PGA_Inv_1_PGA_INV_GAIN_MASK  0x72u
#define PGA_Inv_1_PGA_INV_GAIN_00    0x00u
#define PGA_Inv_1_PGA_INV_GAIN_01    0x10u
#define PGA_Inv_1_PGA_INV_GAIN_03    0x20u
#define PGA_Inv_1_PGA_INV_GAIN_07    0x30u
#define PGA_Inv_1_PGA_INV_GAIN_15    0x40u
#define PGA_Inv_1_PGA_INV_GAIN_22    0x50u
#define PGA_Inv_1_PGA_INV_GAIN_23    0x60u
#define PGA_Inv_1_PGA_INV_GAIN_24    0x70u
#define PGA_Inv_1_PGA_INV_GAIN_31    0x52u
#define PGA_Inv_1_PGA_INV_GAIN_47    0x62u
#define PGA_Inv_1_PGA_INV_GAIN_49    0x72u

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define PGA_Inv_1_ACT_PWR_EN   PGA_Inv_1_SC__PM_ACT_MSK /* Power enable mask */


/***************************************
*              Registers        
***************************************/

#define PGA_Inv_1_CR0    (* (reg8 *) PGA_Inv_1_SC__CR0 )
#define PGA_Inv_1_CR1    (* (reg8 *) PGA_Inv_1_SC__CR1 )
#define PGA_Inv_1_CR2    (* (reg8 *) PGA_Inv_1_SC__CR2 )
#define PGA_Inv_1_PWRMGR (* (reg8 *) PGA_Inv_1_SC__PM_ACT_CFG )  /* Power manager */

#define PGA_Inv_1_SW0    (* (reg8 *) PGA_Inv_1_SC__SW0 )
#define PGA_Inv_1_SW2    (* (reg8 *) PGA_Inv_1_SC__SW2 )
#define PGA_Inv_1_SW3    (* (reg8 *) PGA_Inv_1_SC__SW3 )
#define PGA_Inv_1_SW4    (* (reg8 *) PGA_Inv_1_SC__SW4 )
#define PGA_Inv_1_SW6    (* (reg8 *) PGA_Inv_1_SC__SW6 )
#define PGA_Inv_1_SW7    (* (reg8 *) PGA_Inv_1_SC__SW7 )
#define PGA_Inv_1_SW8    (* (reg8 *) PGA_Inv_1_SC__SW8 )
#define PGA_Inv_1_SW10   (* (reg8 *) PGA_Inv_1_SC__SW10 )
#define PGA_Inv_1_CLK    (* (reg8 *) PGA_Inv_1_SC__CLK )
#define PGA_Inv_1_BST    (* (reg8 *) PGA_Inv_1_SC__BST )

#if (PGA_Inv_1_ACLK_ENABLE)
   #define PGA_Inv_1_ACLK_PWRMGR (* (reg8 *) PGA_Inv_1_ScBoostClk__PM_ACT_CFG )  /* Power manager */
   #define PGA_Inv_1_ACLK_ACT_PWR_EN   PGA_Inv_1_ScBoostClk__PM_ACT_MSK /* Power enable mask */
#endif

#endif /* CY_PGA_Inv_PGA_Inv_1_H */
/* [] END OF FILE */
