/*******************************************************************************
* File Name: Rdrive.c  
* Version 1.10
*
*  Description:
*    This file contains all functions required for the analog multiplexer
*    AMux User Module.
*
*   Note:
*
*******************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "Rdrive.h"
#include "cyfitter_cfg.h"

uint8 Rdrive_lastChannel = Rdrive_NULL_CHANNEL; 

/*******************************************************************************
* Function Name: Rdrive_Start
********************************************************************************
* Summary:
*  This function resets all connections, to disconnected.
*
* Parameters:  
*  (void)
*
* Return: 
*  (void) 
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Rdrive_Start(void) 
{
   Rdrive_DisconnectAll(); 
}


/*******************************************************************************
* Function Name: Rdrive_Stop
********************************************************************************
* Summary:
*  This function disconnects all connections.
*
* Parameters:  
*  (void)
*
* Return: 
*  (void) 
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Rdrive_Stop(void) 
{
   Rdrive_DisconnectAll(); 
}



/*******************************************************************************
* Function Name: Rdrive_Select
********************************************************************************
* Summary:
*  This functions first disconnects all channels then connects the selected
*  channel "channel".
*
* Parameters:  
*  channel:  (uint8) Selects the channel in which to perform the operation.
*
* Return: 
*  (void) Description of return value, if there is a return value.
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Rdrive_Select(uint8 channel) 
{
   Rdrive_DisconnectAll();        /* Disconnect all previous connections */
   Rdrive_Connect(channel);       /* Make the given selection */
   Rdrive_lastChannel = channel;  /* Update last channel */
}

/*******************************************************************************
* Function Name: Rdrive_FastSelect
********************************************************************************
* Summary:
*  This functions first disconnects just the last channel then connects the
*  given channel.
*
* Parameters:  
*  channel:  (uint8) Selects the channel in which to connect.
*
* Return: 
*  None
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Rdrive_FastSelect(uint8 channel) 
{
   /* Disconnect the last valid channel */
   if( Rdrive_lastChannel != Rdrive_NULL_CHANNEL)   /* Update last channel */
   {
      Rdrive_Disconnect(Rdrive_lastChannel);
   }

   /* Make the new channel connection */
   Rdrive_Connect(channel);
   Rdrive_lastChannel = channel;   /* Update last channel */
}

#if(Rdrive_MUXTYPE == Rdrive_MUX_DIFF)
/*******************************************************************************
* Function Name: Rdrive_Connect
********************************************************************************
* Summary:
*  This function connects the given channel, but does not affect any other
*  previous connection.
*
* Parameters:  
*  channel:  (uint8) Selects the channel in which to connect.
*
* Return: 
*  (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Rdrive_Connect(uint8 channel) 
{
   Rdrive_CYAMUXSIDE_A_Set(channel);
   Rdrive_CYAMUXSIDE_B_Set(channel);
}
#endif

#if(Rdrive_MUXTYPE == Rdrive_MUX_DIFF)
/*******************************************************************************
* Function Name: Rdrive_Disconnect
********************************************************************************
* Summary:
*  This function disconnects the given channel from the common or output.  It
*  does not affect any other connection.
*
* Parameters:  
*  channel:  (uint8) Selects the channel in which to disconnect.
*
* Return: 
*  (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Rdrive_Disconnect(uint8 channel) 
{
   Rdrive_CYAMUXSIDE_A_Unset(channel);
   Rdrive_CYAMUXSIDE_B_Unset(channel);
}
#endif

/*******************************************************************************
* Function Name: Rdrive_DisconnectAll
********************************************************************************
* Summary:
*  This function disconnects all channels.
*
* Parameters:  
*  (void)
*
* Return: 
*  (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Rdrive_DisconnectAll(void) 
{
   uint8 chan;

   #if(Rdrive_MUXTYPE == Rdrive_MUX_SINGLE)
      for(chan = 0; chan < Rdrive_CHANNELS ; chan++)
      {
         Rdrive_Unset(chan);
      }
   #else
      for(chan = 0; chan < Rdrive_CHANNELS ; chan++)
      {
         Rdrive_CYAMUXSIDE_A_Unset(chan);
         Rdrive_CYAMUXSIDE_B_Unset(chan);
      }
   #endif
}


/* [] END OF FILE */
