/*******************************************************************************
* File Name: SOC.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "SOC.h"


/*******************************************************************************
* Function Name: SOC_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void SOC_Write(uint8 value)
{
    uint8 staticBits = SOC_DR & ~SOC_MASK;
    SOC_DR = staticBits | ((value << SOC_SHIFT) & SOC_MASK);
}


/*******************************************************************************
* Function Name: SOC_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void SOC_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(SOC_0, mode);
}


/*******************************************************************************
* Function Name: SOC_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SOC_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SOC_Read(void)
{
    return (SOC_PS & SOC_MASK) >> SOC_SHIFT;
}


/*******************************************************************************
* Function Name: SOC_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SOC_ReadDataReg(void)
{
    return (SOC_DR & SOC_MASK) >> SOC_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SOC_INTSTAT) 

    /*******************************************************************************
    * Function Name: SOC_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SOC_ClearInterrupt(void)
    {
        return (SOC_INTSTAT & SOC_MASK) >> SOC_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
