/*******************************************************************************
* File Name: SOC_Go_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "SOC_Go.h"

/* Check for removal by optimization */
#if !defined(SOC_Go_Sync_ctrl_reg__REMOVED)

static SOC_Go_BACKUP_STRUCT  SOC_Go_backup = {0u};

    
/*******************************************************************************
* Function Name: SOC_Go_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SOC_Go_SaveConfig(void) 
{
    SOC_Go_backup.controlState = SOC_Go_Control;
}


/*******************************************************************************
* Function Name: SOC_Go_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void SOC_Go_RestoreConfig(void) 
{
     SOC_Go_Control = SOC_Go_backup.controlState;
}


/*******************************************************************************
* Function Name: SOC_Go_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SOC_Go_Sleep(void) 
{
    SOC_Go_SaveConfig();
}


/*******************************************************************************
* Function Name: SOC_Go_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SOC_Go_Wakeup(void)  
{
    SOC_Go_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
