/***************************************************************************
* File Name: Sign_Change_dma.c  
* Version 1.0
*
*  Description:
*   Provides an API for the DMAC component. The API includes functions
*   for the DMA controller, DMA channels and Transfer Descriptors.
*
*
*   Note:
*     This module requires the developer to finish or fill in the auto
*     generated funcions and setup the dma channel and TD's.
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
#include <CYDEVICE.H>
#include <Sign_Change_dma.H>



/****************************************************************************
* 
* The following defines are available in Cyfitter.h
* 
* 
* 
* Sign_Change__DRQ_CTL_REG
* 
* 
* Sign_Change__DRQ_NUMBER
* 
* Number of TD's used by this channel.
* Sign_Change__NUMBEROF_TDS
* 
* Priority of this channel.
* Sign_Change__PRIORITY
* 
* True if Sign_Change_TERMIN_SEL is used.
* Sign_Change__TERMIN_EN
* 
* TERMIN interrupt line to signal terminate.
* Sign_Change__TERMIN_SEL
* 
* 
* True if Sign_Change_TERMOUT0_SEL is used.
* Sign_Change__TERMOUT0_EN
* 
* 
* TERMOUT0 interrupt line to signal completion.
* Sign_Change__TERMOUT0_SEL
* 
* 
* True if Sign_Change_TERMOUT1_SEL is used.
* Sign_Change__TERMOUT1_EN
* 
* 
* TERMOUT1 interrupt line to signal completion.
* Sign_Change__TERMOUT1_SEL
* 
****************************************************************************/


/* Zero based index of Sign_Change dma channel */
uint8 Sign_Change_DmaHandle = DMA_INVALID_CHANNEL;

/*********************************************************************
* Function Name: uint8 Sign_Change_DmaInitalize
**********************************************************************
* Summary:
*   Allocates and initialises a channel of the DMAC to be used by the
*   caller.
*
* Parameters:
*   BurstCount.
*       
*       
*   ReqestPerBurst.
*       
*       
*   UpperSrcAddress.
*       
*       
*   UpperDestAddress.
*       
*
* Return:
*   The channel that can be used by the caller for DMA activity.
*   DMA_INVALID_CHANNEL (0xFF) if there are no channels left. 
*
*
*******************************************************************/
uint8 Sign_Change_DmaInitialize(uint8 BurstCount, uint8 ReqestPerBurst, uint16 UpperSrcAddress, uint16 UpperDestAddress)
{

    /* Allocate a DMA channel. */
    Sign_Change_DmaHandle = Sign_Change__DRQ_NUMBER;

    CYASSERT((DMA_1_DmaHandle));


    if(Sign_Change_DmaHandle != DMA_INVALID_CHANNEL)
    {
        /* Configure the channel. */
        CyDmaChSetConfiguration(Sign_Change_DmaHandle,
                                BurstCount,
                                ReqestPerBurst,
                                Sign_Change__TERMOUT0_SEL,
                                Sign_Change__TERMOUT1_SEL,
                                Sign_Change__TERMIN_SEL);

        /* Set the extended address for the transfers */
        CyDmaChSetExtendedAddress(Sign_Change_DmaHandle, UpperSrcAddress, UpperDestAddress);

        /* Set the priority for this channel */
        CyDmaChPriority(Sign_Change_DmaHandle, Sign_Change__PRIORITY);
    }

    return Sign_Change_DmaHandle;
}

/*********************************************************************
* Function Name: void Sign_Change_DmaRelease
**********************************************************************
* Summary:
*   Frees the channel associated with Sign_Change.
*
*
* Parameters:
*   void.
*
*
*
* Return:
*   void.
*
*******************************************************************/
void Sign_Change_DmaRelease(void)
{
    /* Disable the channel, even if someone just did! */
    CyDmaChDisable(Sign_Change_DmaHandle);


    /* Free Transfer Descriptors. */


}

