/*******************************************************************************
* File Name: TD_Done.c  
* Version 1.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "TD_Done.h"


/*******************************************************************************
* Function Name: TD_Done_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void TD_Done_Write(uint8 value)
{
    uint8 staticBits = TD_Done_DR & ~TD_Done_MASK;
    TD_Done_DR = staticBits | ((value << TD_Done_SHIFT) & TD_Done_MASK);
}


/*******************************************************************************
* Function Name: TD_Done_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void TD_Done_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(TD_Done_0, mode);
}


/*******************************************************************************
* Function Name: TD_Done_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro TD_Done_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 TD_Done_Read(void)
{
    return (TD_Done_PS & TD_Done_MASK) >> TD_Done_SHIFT;
}


/*******************************************************************************
* Function Name: TD_Done_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 TD_Done_ReadDataReg(void)
{
    return (TD_Done_DR & TD_Done_MASK) >> TD_Done_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(TD_Done_INTSTAT) 

    /*******************************************************************************
    * Function Name: TD_Done_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 TD_Done_ClearInterrupt(void)
    {
        return (TD_Done_INTSTAT & TD_Done_MASK) >> TD_Done_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
