/*******************************************************************************
* File Name: TIA_Buffer.h  
* Version 1.20
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the PGA User Module.
*
*   Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_PGA_TIA_Buffer_H) 
#define CY_PGA_TIA_Buffer_H 

/***************************************
*        Function Prototypes 
***************************************/

void    TIA_Buffer_Start(void);
void    TIA_Buffer_Stop(void);
void    TIA_Buffer_SetPower(uint8 power);
void    TIA_Buffer_SetGain(uint8 gain);


/***************************************
*       Initialization Values
***************************************/

#define TIA_Buffer_DEFAULT_GAIN  0
#define TIA_Buffer_VREF_MODE     (0 ? 0x00 : TIA_Buffer_GNDVREF_E )
#define TIA_Buffer_DEFAULT_POWER 3
/* #define TIA_Buffer_ACLK_ENABLE   ((0 ? 0 : 1) | 0 )  */
#define TIA_Buffer_ACLK_ENABLE   0 

/***************************************
*              Registers        
***************************************/

#define TIA_Buffer_CR0    (* (reg8 *) TIA_Buffer_SC__CR0 )
#define TIA_Buffer_CR1    (* (reg8 *) TIA_Buffer_SC__CR1 )
#define TIA_Buffer_CR2    (* (reg8 *) TIA_Buffer_SC__CR2 )
#define TIA_Buffer_PWRMGR (* (reg8 *) TIA_Buffer_SC__PM_ACT_CFG )  /* Power manager */
#define TIA_Buffer_BST    (* (reg8 *) TIA_Buffer_SC__BST )

#if (TIA_Buffer_ACLK_ENABLE)
   #define TIA_Buffer_ACLK_PWRMGR (* (reg8 *) TIA_Buffer_ScBoostClk__PM_ACT_CFG )  /* Power manager */
   #define TIA_Buffer_ACLK_ACT_PWR_EN   TIA_Buffer_ScBoostClk__PM_ACT_MSK /* Power enable mask */
#endif

/***************************************
*              Constants        
***************************************/

/* Power constants for SetPower function */
#define TIA_Buffer_MINPOWER   0x00u
#define TIA_Buffer_LOWPOWER   0x01u
#define TIA_Buffer_MEDPOWER   0x02u
#define TIA_Buffer_HIGHPOWER  0x03u

/* Constants for SetGain function */
#define TIA_Buffer_GAIN_01    0x00u
#define TIA_Buffer_GAIN_02    0x01u
#define TIA_Buffer_GAIN_04    0x02u
#define TIA_Buffer_GAIN_08    0x03u
#define TIA_Buffer_GAIN_16    0x04u
#define TIA_Buffer_GAIN_24    0x05u
#define TIA_Buffer_GAIN_25    0x06u
#define TIA_Buffer_GAIN_32    0x07u
#define TIA_Buffer_GAIN_48    0x08u
#define TIA_Buffer_GAIN_50    0x09u
#define TIA_Buffer_GAIN_MAX   0x09u


/* CR0 SC/CT Control Register 0 definitions */
#define TIA_Buffer_MODE_PGA      0x0Cu

/* CR1 SC/CT Control Register 1 definitions */
/* Bit Field  SC_COMP_ENUM                  */
#define TIA_Buffer_COMP_MASK     0x0Cu
#define TIA_Buffer_COMP_3P0PF    0x00u
#define TIA_Buffer_COMP_3P6PF    0x04u
#define TIA_Buffer_COMP_4P35PF   0x08u
#define TIA_Buffer_COMP_5P1PF    0x0Cu

/* Bit Field  SC_DIV2_ENUM                  */
#define TIA_Buffer_DIV2_MASK     0x10u
#define TIA_Buffer_DIV2_DISABLE  0x00u
#define TIA_Buffer_DIV2_ENABLE   0x10u

/* Bit Field  SC_DRIVE_ENUM                 */
#define TIA_Buffer_DRIVE_MASK    0x03u
#define TIA_Buffer_DRIVE_280UA   0x00u
#define TIA_Buffer_DRIVE_420UA   0x01u
#define TIA_Buffer_DRIVE_530UA   0x02u
#define TIA_Buffer_DRIVE_650UA   0x03u

/* Bit Field  SC_PGA_MODE_ENUM              */
#define TIA_Buffer_PGA_MODE_MASK 0x20u
#define TIA_Buffer_PGA_INV       0x00u
#define TIA_Buffer_PGA_NINV      0x20u

/* CR2 SC/CT Control Register 2 definitions */

/* Bit Field  SC_BIAS_CONTROL_ENUM          */
#define TIA_Buffer_BIAS_MASK     0x01u
#define TIA_Buffer_BIAS_NORMAL   0x00u
#define TIA_Buffer_BIAS_LOW      0x01u

/* Bit Field  SC_PGA_GNDVREF_ENUM           */
#define TIA_Buffer_GNDVREF_MASK  0x80u
#define TIA_Buffer_GNDVREF_DI    0x00u
#define TIA_Buffer_GNDVREF_E     0x80u

/* Bit Field  SC_R20_40B_ENUM               */
#define TIA_Buffer_R20_40B_MASK  0x02u
#define TIA_Buffer_R20_40B_40K   0x00u
#define TIA_Buffer_R20_40B_20K   0x02u

/* Bit Field  SC_REDC_ENUM                  */
#define TIA_Buffer_REDC_MASK     0x0Cu
#define TIA_Buffer_REDC_00       0x00u
#define TIA_Buffer_REDC_01       0x04u
#define TIA_Buffer_REDC_10       0x08u
#define TIA_Buffer_REDC_11       0x0Cu

/* Bit Field  SC_RVAL_ENUM                  */
#define TIA_Buffer_RVAL_MASK     0x70u
#define TIA_Buffer_RVAL_20K      0x00u
#define TIA_Buffer_RVAL_30K      0x10u
#define TIA_Buffer_RVAL_40K      0x20u
#define TIA_Buffer_RVAL_60K      0x30u
#define TIA_Buffer_RVAL_120K     0x40u
#define TIA_Buffer_RVAL_250K     0x50u
#define TIA_Buffer_RVAL_500K     0x60u
#define TIA_Buffer_RVAL_1000K    0x70u

/* Bit Field  PGA_GAIN_ENUM    */
#define TIA_Buffer_PGA_GAIN_MASK  0x72u
#define TIA_Buffer_PGA_GAIN_01    0x00u
#define TIA_Buffer_PGA_GAIN_02    0x10u
#define TIA_Buffer_PGA_GAIN_04    0x20u
#define TIA_Buffer_PGA_GAIN_08    0x30u
#define TIA_Buffer_PGA_GAIN_16    0x40u
#define TIA_Buffer_PGA_GAIN_24    0x50u
#define TIA_Buffer_PGA_GAIN_25    0x70u
#define TIA_Buffer_PGA_GAIN_32    0x52u
#define TIA_Buffer_PGA_GAIN_48    0x62u
#define TIA_Buffer_PGA_GAIN_50    0x72u

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define TIA_Buffer_ACT_PWR_EN   TIA_Buffer_SC__PM_ACT_MSK /* Power enable mask */

#endif /* CY_PGA_TIA_Buffer_H */

/* [] END OF FILE */

