/*******************************************************************************
* File Name: isr_SOC_intc.c  
* Version 1.10
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <isr_SOC.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START isr_SOC_intc` */

extern uint8 SOC_Flag;

/* `#END` */


/*******************************************************************************
* Function Name: isr_SOC_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void isr_SOC_Start(void)
{
    /* For all we know the interrupt is active. */
    isr_SOC_Disable();

    /* Set the ISR to point to the isr_SOC Interrupt. */
    isr_SOC_SetVector(isr_SOC_Interrupt);

    /* Set the priority. */
    isr_SOC_SetPriority(isr_SOC_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isr_SOC_Enable();
}

/*******************************************************************************
* Function Name: isr_SOC_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void isr_SOC_Stop(void)
{
    /* Disable this interrupt. */
    isr_SOC_Disable();

    /* Set the ISR to point to the passive one. */
//    isr_SOC_SetVector(CyDefaultInterrupt);
}

/*******************************************************************************
* Function Name: isr_SOC_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for isr_SOC.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(isr_SOC_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START isr_SOC_Interrupt` */

	if(SOC_Flag == 0)
	{
		SOC_Flag = 1;
	}

    /* `#END` */
}


/*******************************************************************************
* Function Name: isr_SOC_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_SOC_SetVector(cyisraddress address)
{
    CY_SET_REG16(isr_SOC_INTC_VECTOR, (uint16) address);
}

/*******************************************************************************
* Function Name: isr_SOC_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress isr_SOC_GetVector(void)
{
    return (cyisraddress) CY_GET_REG16(isr_SOC_INTC_VECTOR);
}

/*******************************************************************************
* Function Name: isr_SOC_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_SOC_SetPriority(uint8 priority)
{
    *isr_SOC_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: isr_SOC_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 isr_SOC_GetPriority(void)
{
    uint8 priority;


    priority = *isr_SOC_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: isr_SOC_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_SOC_Enable(void)
{
    /* Enable the general interrupt. */
    *isr_SOC_INTC_SET_EN = isr_SOC__INTC_MASK;
}

/*******************************************************************************
* Function Name: isr_SOC_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 isr_SOC_GetState(void)
{
    /* Get the state of the general interrupt. */
    return (*isr_SOC_INTC_SET_EN & isr_SOC__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: isr_SOC_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_SOC_Disable(void)
{
    /* Disable the general interrupt. */
    *isr_SOC_INTC_CLR_EN = isr_SOC__INTC_MASK;
}

/*******************************************************************************
* Function Name: isr_SOC_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_SOC_SetPending(void)
{
    *isr_SOC_INTC_SET_PD = isr_SOC__INTC_MASK;
}

/*******************************************************************************
* Function Name: isr_SOC_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_SOC_ClearPending(void)
{
    *isr_SOC_INTC_CLR_PD = isr_SOC__INTC_MASK;
}


















































