/*******************************************************************************
* File Name: Agnd.h  
* Version 1.20
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the 8-bit Voltage DAC (vDAC8) User Module.
*
*   Note:
*     
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_VDAC8_Agnd_H) 
#define CY_VDAC8_Agnd_H

/* TODO: Remove this line after changes to DAC */
#define Agnd_FIRST_SILICON 

/***************************************
*        Function Prototypes 
***************************************/

void    Agnd_Start(void);
void    Agnd_Stop(void);
void    Agnd_SetSpeed(uint8 speed);
void    Agnd_SetRange(uint8 range);
void    Agnd_SetValue(uint8 value);
void 	Agnd_DacTrim(void);
  
  
/***************************************
*            API Constants
***************************************/

/* SetRange constants */

#define Agnd_RANGE_1V       0x00u
#define Agnd_RANGE_4V       0x04u


/* Power setting for Start API  */
#define Agnd_LOWSPEED       0x00u
#define Agnd_HIGHSPEED      0x02u


/***************************************
*  Initialization Parameter Constants
***************************************/

#define Agnd_DEFAULT_RANGE    4     /* Default DAC range */
#define Agnd_DEFAULT_SPEED    2     /* Default DAC speed */
#define Agnd_DEFAULT_CNTL     0x00u             /* Default Control */
#define Agnd_DEFAULT_STRB     0    /* Default Strobe mode */
#define Agnd_DEFAULT_DATA     156  /* Initial DAC value */
#define Agnd_DEFAULT_DATA_SRC 0    /* Default Data Source */


/***************************************
*              Registers        
***************************************/

#define Agnd_CR0    (* (reg8 *) Agnd_viDAC8__CR0 )
#define Agnd_CR1    (* (reg8 *) Agnd_viDAC8__CR1 )
#define Agnd_Data   (* (reg8 *) Agnd_viDAC8__D )
#define Agnd_Strobe (* (reg8 *) Agnd_viDAC8__STROBE )
#define Agnd_SW0    (* (reg8 *) Agnd_viDAC8__SW0 )
#define Agnd_SW2    (* (reg8 *) Agnd_viDAC8__SW2 )
#define Agnd_SW3    (* (reg8 *) Agnd_viDAC8__SW3 )
#define Agnd_SW4    (* (reg8 *) Agnd_viDAC8__SW4 )
#define Agnd_TR     (* (reg8 *) Agnd_viDAC8__TR )
#define Agnd_PWRMGR (* (reg8 *) Agnd_viDAC8__PM_ACT_CFG )  /* Power manager */


/***************************************
*         Register Constants       
***************************************/

/* CR0 vDac Control Register 0 definitions */

/* Bit Field  DAC_HS_MODE                  */
#define Agnd_HS_MASK        0x02u
#define Agnd_HS_LOWPOWER    0x00u
#define Agnd_HS_HIGHSPEED   0x02u

/* Bit Field  DAC_MODE                  */
#define Agnd_MODE_MASK      0x10u
#define Agnd_MODE_V         0x00u
#define Agnd_MODE_I         0x10u

/* Bit Field  DAC_RANGE                  */
#define Agnd_RANGE_MASK     0x0Cu
#define Agnd_RANGE_0        0x00u
#define Agnd_RANGE_1        0x04u

/* CR1 iDac Control Register 1 definitions */

/* Bit Field  DAC_MX_DATA                  */
#define Agnd_SRC_MASK       0x20u
#define Agnd_SRC_REG        0x00u
#define Agnd_SRC_UDB        0x20u

/* This bit enable reset from UDB array      */
#define Agnd_RESET_MASK     0x10u
#define Agnd_RESET_ENABLE   0x10u
#define Agnd_RESET_DISABLE  0x00u

/* This bit enables data from DAC bus      */
#define Agnd_DACBUS_MASK     0x20u
#define Agnd_DACBUS_ENABLE   0x20u
#define Agnd_DACBUS_DISABLE  0x00u

/* DAC STROBE Strobe Control Register definitions */

/* Bit Field  DAC_MX_STROBE                  */
#define Agnd_STRB_MASK     0x08u
#define Agnd_STRB_EN       0x08u
#define Agnd_STRB_DIS      0x00u

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#if !defined(Agnd_FIRST_SILICON)
#define Agnd_ACT_PWR_EN   Agnd_viDAC8__PM_ACT_MSK /* Power enable mask */ 
#else
#define Agnd_ACT_PWR_EN   0xFF /* TODO: Work around for incorrect power enable */
#endif

/***************************************
*              Trim    
* Note - VIDAC trim values are stored in the "Customer Table" area in 
* Row 1 of the Hidden Flash.  There are 8 bytes of trim data for each VIDAC block.
* The values are:
*       I Gain offset, min range, Sourcing
*       I Gain offset, min range, Sinking
*       I Gain offset, med range, Sourcing
*       I Gain offset, med range, Sinking
*       I Gain offset, max range, Sourcing
*       I Gain offset, max range, Sinking
*       V Gain offset, 1V range
*       V Gain offset, 4V range
*
* The data set for the 4 VIDACs are arranged using a left side/right side approach:
*   Left 0, Left 1, Right 0, Right 1.
* When mapped to the VIDAC0 thru VIDAC3 as:
*   VIDAC 0, VIDAC 2, VIDAC 1, VIDAC 3
***************************************/
#define Agnd_TRIM_M7_1V_RNG_OFFSET  0x06u
#define Agnd_TRIM_M8_4V_RNG_OFFSET  0x07u


#define Agnd_DAC_POS  (Agnd_viDAC8__D - CYDEV_ANAIF_WRK_DAC0_BASE)

/* DAC offset address from CYDEV_FLSHID_BASE */
#define Agnd_DAC0_OFFSET 0x00011Cu
#define Agnd_DAC1_OFFSET 0x000112u
#define Agnd_DAC2_OFFSET 0x000124u
#define Agnd_DAC3_OFFSET 0x000134u

/* Trim base address for DACs at position 0, 1, 2 and 3 */
#if(Agnd_DAC_POS == 0)
#define Agnd_DAC_TRIM_BASE   CYDEV_FLSHID_BASE + Agnd_DAC0_OFFSET
#endif

#if(Agnd_DAC_POS == 1)
#define Agnd_DAC_TRIM_BASE   CYDEV_FLSHID_BASE + Agnd_DAC1_OFFSET
#endif

#if(Agnd_DAC_POS == 2)
#define Agnd_DAC_TRIM_BASE   CYDEV_FLSHID_BASE + Agnd_DAC2_OFFSET
#endif

#if(Agnd_DAC_POS == 3)
#define Agnd_DAC_TRIM_BASE   CYDEV_FLSHID_BASE + Agnd_DAC3_OFFSET
#endif

#endif /* CY_VDAC8_Agnd_H  */
/* [] END OF FILE */

