/*******************************************************************************
* File Name: Agnd_Buffer.c
* Version 1.10
*
* Description:
*   This file provides the source code to the API for the OpAmp (Analog Buffer) 
*   User Module.
*
* NOTE:
* 
*
*******************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "Agnd_Buffer.h"

uint8  Agnd_Buffer_initVar = 0;

/*******************************************************************************
* Funciton Name:   Agnd_Buffer_Start
********************************************************************************
*
* Summary:
*  The start function initializes the Analog Buffer with the default values, and 
*  sets the power to the given level.  A power level of 0, is the same as 
*  executing the stop function.
*
* Parameters: 
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void Agnd_Buffer_Start(void) 
{
   if(Agnd_Buffer_initVar == 0)
   {
      Agnd_Buffer_initVar = 1;
      Agnd_Buffer_SetPower(Agnd_Buffer_DEFAULT_POWER);

      /* Set follower mode if selected */
      Agnd_Buffer_SW |= Agnd_Buffer_DEFAULT_MODE;
   }
	
	/*Enable negative charge pumps in ANIF*/
 	Agnd_Buffer_PUMP_CR1  |= (Agnd_Buffer_PUMP_CR1_CLKSEL | Agnd_Buffer_PUMP_CR1_FORCE );
	
	/* Enable power to buffer */
   Agnd_Buffer_PWRMGR |= Agnd_Buffer_ACT_PWR_EN;
   
}


/*******************************************************************************
* Function Name: Agnd_Buffer_Stop
********************************************************************************
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:  
*   (void)
*
* Return:  
*   (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Agnd_Buffer_Stop(void)
{
	/*Disable negative charge pumps for ANIF only if the one ABuf is turned ON*/
   	if(Agnd_Buffer_PWRMGR == Agnd_Buffer_ACT_PWR_EN)
   	{
	    Agnd_Buffer_PUMP_CR1 &= ~(Agnd_Buffer_PUMP_CR1_CLKSEL | Agnd_Buffer_PUMP_CR1_FORCE );
	}
	
	/* Disable power to buffer */
	Agnd_Buffer_PWRMGR &= ~Agnd_Buffer_ACT_PWR_EN;
		
}

/*******************************************************************************
* Funciton Name:   Agnd_Buffer_SetPower
********************************************************************************
*
* Summary:
*  Sets power level of Analog buffer.
*
* Parameters: 
*    power:   Sets power level between low (1) and high power (3).
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void Agnd_Buffer_SetPower(uint8 power) 
{
      Agnd_Buffer_CR &= ~Agnd_Buffer_PWR_MASK;             /* Clear power setting  */
      Agnd_Buffer_CR |= ( power & Agnd_Buffer_PWR_MASK);   /* Set device power     */
}
/* [] END OF FILE */


