/*******************************************************************************
* File Name: Excitation_Drive.c
* Version 1.10
*
* Description:
*   This file provides the source code to the API for the OpAmp (Analog Buffer) 
*   User Module.
*
* NOTE:
* 
*
*******************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "Excitation_Drive.h"

uint8  Excitation_Drive_initVar = 0;

/*******************************************************************************
* Funciton Name:   Excitation_Drive_Start
********************************************************************************
*
* Summary:
*  The start function initializes the Analog Buffer with the default values, and 
*  sets the power to the given level.  A power level of 0, is the same as 
*  executing the stop function.
*
* Parameters: 
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void Excitation_Drive_Start(void) 
{
   if(Excitation_Drive_initVar == 0)
   {
      Excitation_Drive_initVar = 1;
      Excitation_Drive_SetPower(Excitation_Drive_DEFAULT_POWER);

      /* Set follower mode if selected */
      Excitation_Drive_SW |= Excitation_Drive_DEFAULT_MODE;
   }
	
	/*Enable negative charge pumps in ANIF*/
 	Excitation_Drive_PUMP_CR1  |= (Excitation_Drive_PUMP_CR1_CLKSEL | Excitation_Drive_PUMP_CR1_FORCE );
	
	/* Enable power to buffer */
   Excitation_Drive_PWRMGR |= Excitation_Drive_ACT_PWR_EN;
   
}


/*******************************************************************************
* Function Name: Excitation_Drive_Stop
********************************************************************************
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:  
*   (void)
*
* Return:  
*   (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void Excitation_Drive_Stop(void)
{
	/*Disable negative charge pumps for ANIF only if the one ABuf is turned ON*/
   	if(Excitation_Drive_PWRMGR == Excitation_Drive_ACT_PWR_EN)
   	{
	    Excitation_Drive_PUMP_CR1 &= ~(Excitation_Drive_PUMP_CR1_CLKSEL | Excitation_Drive_PUMP_CR1_FORCE );
	}
	
	/* Disable power to buffer */
	Excitation_Drive_PWRMGR &= ~Excitation_Drive_ACT_PWR_EN;
		
}

/*******************************************************************************
* Funciton Name:   Excitation_Drive_SetPower
********************************************************************************
*
* Summary:
*  Sets power level of Analog buffer.
*
* Parameters: 
*    power:   Sets power level between low (1) and high power (3).
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void Excitation_Drive_SetPower(uint8 power) 
{
      Excitation_Drive_CR &= ~Excitation_Drive_PWR_MASK;             /* Clear power setting  */
      Excitation_Drive_CR |= ( power & Excitation_Drive_PWR_MASK);   /* Set device power     */
}
/* [] END OF FILE */


