/*******************************************************************************
* File Name: Phase_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Phase.h"

/* Check for removal by optimization */
#if !defined(Phase_Sync_ctrl_reg__REMOVED)

static Phase_BACKUP_STRUCT  Phase_backup = {0u};

    
/*******************************************************************************
* Function Name: Phase_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Phase_SaveConfig(void) 
{
    Phase_backup.controlState = Phase_Control;
}


/*******************************************************************************
* Function Name: Phase_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Phase_RestoreConfig(void) 
{
     Phase_Control = Phase_backup.controlState;
}


/*******************************************************************************
* Function Name: Phase_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Phase_Sleep(void) 
{
    Phase_SaveConfig();
}


/*******************************************************************************
* Function Name: Phase_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Phase_Wakeup(void)  
{
    Phase_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
