/***************************************************************************
* File Name: Sine_Table_dma.c  
* Version 1.0
*
*  Description:
*   Provides an API for the DMAC component. The API includes functions
*   for the DMA controller, DMA channels and Transfer Descriptors.
*
*
*   Note:
*     This module requires the developer to finish or fill in the auto
*     generated funcions and setup the dma channel and TD's.
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
#include <CYDEVICE.H>
#include <Sine_Table_dma.H>



/****************************************************************************
* 
* The following defines are available in Cyfitter.h
* 
* 
* 
* Sine_Table__DRQ_CTL_REG
* 
* 
* Sine_Table__DRQ_NUMBER
* 
* Number of TD's used by this channel.
* Sine_Table__NUMBEROF_TDS
* 
* Priority of this channel.
* Sine_Table__PRIORITY
* 
* True if Sine_Table_TERMIN_SEL is used.
* Sine_Table__TERMIN_EN
* 
* TERMIN interrupt line to signal terminate.
* Sine_Table__TERMIN_SEL
* 
* 
* True if Sine_Table_TERMOUT0_SEL is used.
* Sine_Table__TERMOUT0_EN
* 
* 
* TERMOUT0 interrupt line to signal completion.
* Sine_Table__TERMOUT0_SEL
* 
* 
* True if Sine_Table_TERMOUT1_SEL is used.
* Sine_Table__TERMOUT1_EN
* 
* 
* TERMOUT1 interrupt line to signal completion.
* Sine_Table__TERMOUT1_SEL
* 
****************************************************************************/


/* Zero based index of Sine_Table dma channel */
uint8 Sine_Table_DmaHandle = DMA_INVALID_CHANNEL;

/*********************************************************************
* Function Name: uint8 Sine_Table_DmaInitalize
**********************************************************************
* Summary:
*   Allocates and initialises a channel of the DMAC to be used by the
*   caller.
*
* Parameters:
*   BurstCount.
*       
*       
*   ReqestPerBurst.
*       
*       
*   UpperSrcAddress.
*       
*       
*   UpperDestAddress.
*       
*
* Return:
*   The channel that can be used by the caller for DMA activity.
*   DMA_INVALID_CHANNEL (0xFF) if there are no channels left. 
*
*
*******************************************************************/
uint8 Sine_Table_DmaInitialize(uint8 BurstCount, uint8 ReqestPerBurst, uint16 UpperSrcAddress, uint16 UpperDestAddress)
{

    /* Allocate a DMA channel. */
    Sine_Table_DmaHandle = Sine_Table__DRQ_NUMBER;

    CYASSERT((DMA_1_DmaHandle));


    if(Sine_Table_DmaHandle != DMA_INVALID_CHANNEL)
    {
        /* Configure the channel. */
        CyDmaChSetConfiguration(Sine_Table_DmaHandle,
                                BurstCount,
                                ReqestPerBurst,
                                Sine_Table__TERMOUT0_SEL,
                                Sine_Table__TERMOUT1_SEL,
                                Sine_Table__TERMIN_SEL);

        /* Set the extended address for the transfers */
        CyDmaChSetExtendedAddress(Sine_Table_DmaHandle, UpperSrcAddress, UpperDestAddress);

        /* Set the priority for this channel */
        CyDmaChPriority(Sine_Table_DmaHandle, Sine_Table__PRIORITY);
    }

    return Sine_Table_DmaHandle;
}

/*********************************************************************
* Function Name: void Sine_Table_DmaRelease
**********************************************************************
* Summary:
*   Frees the channel associated with Sine_Table.
*
*
* Parameters:
*   void.
*
*
*
* Return:
*   void.
*
*******************************************************************/
void Sine_Table_DmaRelease(void)
{
    /* Disable the channel, even if someone just did! */
    CyDmaChDisable(Sine_Table_DmaHandle);


    /* Free Transfer Descriptors. */


}

